# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v0/environments/configuration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0 import runtime_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_runtime__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import network_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_network__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7qwak/administration/v0/environments/configuration.proto\x12\x1fqwak.administration.environment\x1a\x41qwak/administration/runtime_configuration/v0/runtime_config.proto\x1a\x41qwak/administration/runtime_configuration/v0/network_config.proto\"\xfe\x04\n\x1cQwakEnvironmentConfiguration\x12\x19\n\x11\x65\x64ge_services_url\x18\x01 \x01(\t\x12\x1d\n\x15management_access_url\x18\x06 \x01(\t\x12\x15\n\rmodel_api_url\x18\x02 \x01(\t\x12\x1e\n\x16\x61nalytics_data_api_url\x18\x03 \x01(\t\x12\x1d\n\x15object_storage_bucket\x18\x04 \x01(\t\x12\x19\n\x11\x62i_system_api_key\x18\x05 \x01(\t\x12T\n\x13\x63loud_configuration\x18\x07 \x01(\x0b\x32\x37.qwak.administration.environment.QwakCloudConfiguration\x12_\n\x1b\x66\x65\x61ture_store_configuration\x18\x08 \x01(\x0b\x32:.qwak.administration.environment.FeatureStoreConfiguration\x12!\n\x19\x63ontainer_registry_prefix\x18\t \x01(\t\x12]\n\x1a\x63ommunication_manager_type\x18\n \x01(\x0e\x32\x39.qwak.administration.environment.CommunicationManagerType\x12_\n\x1a\x65nvironment_runtime_config\x18\x0b \x01(\x0b\x32\x39.qwak.administration.environment.EnvironmentRuntimeConfigH\x00\x42\x19\n\x17optional_runtime_config\"v\n\x19\x46\x65\x61tureStoreConfiguration\x12\x1d\n\x15\x61irflow_connection_id\x18\x01 \x01(\t\x12\x15\n\rredis_address\x18\x02 \x01(\t\x12#\n\x1buser_code_execution_allowed\x18\x03 \x01(\x08\"\xdf\x01\n\x16QwakCloudConfiguration\x12Y\n\x17\x61ws_cloud_configuration\x18\x01 \x01(\x0b\x32\x36.qwak.administration.environment.AwsCloudConfigurationH\x00\x12Y\n\x17gcp_cloud_configuration\x18\x02 \x01(\x0b\x32\x36.qwak.administration.environment.GcpCloudConfigurationH\x00\x42\x0f\n\rconfiguration\"\xae\x01\n\x15\x41wsCloudConfiguration\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\x10\n\x08role_arn\x18\x02 \x01(\t\x12K\n\x11\x66\x65\x61ture_store_emr\x18\x03 \x01(\x0b\x32\x30.qwak.administration.environment.FeatureStoreEmr\x12\x13\n\x0b\x65xternal_id\x18\x04 \x01(\t\x12\x11\n\tworkgroup\x18\x05 \x01(\t\"\xb0\x01\n\x15GcpCloudConfiguration\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06region\x18\x02 \x01(\t\x12 \n\x18\x62ig_lake_connection_name\x18\x03 \x01(\t\x12\x19\n\x11\x62ig_lake_location\x18\x04 \x01(\t\x12\x17\n\x0fservice_account\x18\x05 \x01(\t\x12\x1d\n\x15\x62ig_lake_catalog_name\x18\x06 \x01(\t\"\xc5\x01\n\x0f\x46\x65\x61tureStoreEmr\x12\x14\n\x0c\x65\x63\x32_key_name\x18\x01 \x01(\t\x12\x15\n\rec2_subnet_id\x18\x02 \x01(\t\x12\x19\n\x11\x65mr_job_flow_role\x18\x03 \x01(\t\x12\x18\n\x10\x65mr_service_role\x18\x04 \x01(\t\x12%\n\x1d\x65\x63\x32_additional_security_group\x18\x05 \x01(\t\x12)\n!target_on_demand_capacity_workers\x18\x06 \x01(\x05\"\xfa\x01\n\x18\x45nvironmentRuntimeConfig\x12\x61\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfiguration\x12{\n\x15network_configuration\x18\x02 \x01(\x0b\x32\\.qwak.administration.runtime_configuration.v0.network_config.EnvironmentNetworkConfiguration*X\n\x18\x43ommunicationManagerType\x12\x13\n\x0fINVALID_MANAGER\x10\x00\x12\x12\n\x0e\x44IRECT_MANAGER\x10\x01\x12\x13\n\x0f\x41\x44MIRAL_MANAGER\x10\x02\x42\xb2\x01\n\x1e\x63om.qwak.ai.administration.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.v0.environments.configuration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036com.qwak.ai.administration.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v0/environments;environment_v0'
  _globals['_COMMUNICATIONMANAGERTYPE']._serialized_start=2022
  _globals['_COMMUNICATIONMANAGERTYPE']._serialized_end=2110
  _globals['_QWAKENVIRONMENTCONFIGURATION']._serialized_start=227
  _globals['_QWAKENVIRONMENTCONFIGURATION']._serialized_end=865
  _globals['_FEATURESTORECONFIGURATION']._serialized_start=867
  _globals['_FEATURESTORECONFIGURATION']._serialized_end=985
  _globals['_QWAKCLOUDCONFIGURATION']._serialized_start=988
  _globals['_QWAKCLOUDCONFIGURATION']._serialized_end=1211
  _globals['_AWSCLOUDCONFIGURATION']._serialized_start=1214
  _globals['_AWSCLOUDCONFIGURATION']._serialized_end=1388
  _globals['_GCPCLOUDCONFIGURATION']._serialized_start=1391
  _globals['_GCPCLOUDCONFIGURATION']._serialized_end=1567
  _globals['_FEATURESTOREEMR']._serialized_start=1570
  _globals['_FEATURESTOREEMR']._serialized_end=1767
  _globals['_ENVIRONMENTRUNTIMECONFIG']._serialized_start=1770
  _globals['_ENVIRONMENTRUNTIMECONFIG']._serialized_end=2020
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/automation_management_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.automation.v1 import automation_pb2 as qwak_dot_automation_dot_v1_dot_automation__pb2
from _qwak_proto.qwak.automation.v1 import automation_execution_pb2 as qwak_dot_automation_dot_v1_dot_automation__execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6qwak/automation/v1/automation_management_service.proto\x12\x12qwak.automation.v1\x1a#qwak/automation/v1/automation.proto\x1a-qwak/automation/v1/automation_execution.proto\"V\n\x17\x43reateAutomationRequest\x12;\n\x0f\x61utomation_spec\x18\x01 \x01(\x0b\x32\".qwak.automation.v1.AutomationSpec\"1\n\x18\x43reateAutomationResponse\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"m\n\x17UpdateAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12;\n\x0f\x61utomation_spec\x18\x02 \x01(\x0b\x32\".qwak.automation.v1.AutomationSpec\"\x1a\n\x18UpdateAutomationResponse\"0\n\x17\x44\x65leteAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"\x1a\n\x18\x44\x65leteAutomationResponse\"*\n\x16ListAutomationsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"N\n\x17ListAutomationsResponse\x12\x33\n\x0b\x61utomations\x18\x01 \x03(\x0b\x32\x1e.qwak.automation.v1.Automation\"-\n\x14GetAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"K\n\x15GetAutomationResponse\x12\x32\n\nautomation\x18\x01 \x01(\x0b\x32\x1e.qwak.automation.v1.Automation\"5\n\x1aGetAutomationByNameRequest\x12\x17\n\x0f\x61utomation_name\x18\x01 \x01(\t\"Q\n\x1bGetAutomationByNameResponse\x12\x32\n\nautomation\x18\x01 \x01(\x0b\x32\x1e.qwak.automation.v1.Automation\"k\n\x1fListAutomationExecutionsRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x31\n\ndate_range\x18\x02 \x01(\x0b\x32\x1d.qwak.automation.v1.DateRange\"q\n ListAutomationExecutionsResponse\x12M\n\x15\x61utomation_executions\x18\x01 \x03(\x0b\x32..qwak.automation.v1.AutomationExecutionMessage\"7\n#ListLastAutomationExecutionsRequest\x12\x10\n\x08model_id\x18\x01 \x01(\t\"\xbe\x02\n$ListLastAutomationExecutionsResponse\x12\x97\x01\n*last_automation_execution_by_automation_id\x18\x01 \x03(\x0b\x32\x63.qwak.automation.v1.ListLastAutomationExecutionsResponse.LastAutomationExecutionByAutomationIdEntry\x1a|\n*LastAutomationExecutionByAutomationIdEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..qwak.automation.v1.AutomationExecutionMessage:\x02\x38\x01\"Q\n\"RegisterAutomationExecutionRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x02 \x01(\t\"%\n#RegisterAutomationExecutionResponse\"}\n UpdateAutomationExecutionRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\x12\x43\n\x0brun_details\x18\x02 \x01(\x0b\x32..qwak.automation.v1.ExecutionRunDetailsMessage\"#\n!UpdateAutomationExecutionResponse\"L\n\x1fToggleAutomationActivityRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\"\"\n ToggleAutomationActivityResponse\"-\n\x14RunAutomationRequest\x12\x15\n\rautomation_id\x18\x01 \x01(\t\"\x17\n\x15RunAutomationResponse2\xda\x0b\n\x1b\x41utomationManagementService\x12m\n\x10\x43reateAutomation\x12+.qwak.automation.v1.CreateAutomationRequest\x1a,.qwak.automation.v1.CreateAutomationResponse\x12m\n\x10UpdateAutomation\x12+.qwak.automation.v1.UpdateAutomationRequest\x1a,.qwak.automation.v1.UpdateAutomationResponse\x12m\n\x10\x44\x65leteAutomation\x12+.qwak.automation.v1.DeleteAutomationRequest\x1a,.qwak.automation.v1.DeleteAutomationResponse\x12\x64\n\rGetAutomation\x12(.qwak.automation.v1.GetAutomationRequest\x1a).qwak.automation.v1.GetAutomationResponse\x12v\n\x13GetAutomationByName\x12..qwak.automation.v1.GetAutomationByNameRequest\x1a/.qwak.automation.v1.GetAutomationByNameResponse\x12j\n\x0fListAutomations\x12*.qwak.automation.v1.ListAutomationsRequest\x1a+.qwak.automation.v1.ListAutomationsResponse\x12\x85\x01\n\x18ListAutomationExecutions\x12\x33.qwak.automation.v1.ListAutomationExecutionsRequest\x1a\x34.qwak.automation.v1.ListAutomationExecutionsResponse\x12\x91\x01\n\x1cListLastAutomationExecutions\x12\x37.qwak.automation.v1.ListLastAutomationExecutionsRequest\x1a\x38.qwak.automation.v1.ListLastAutomationExecutionsResponse\x12\x8e\x01\n\x1bRegisterAutomationExecution\x12\x36.qwak.automation.v1.RegisterAutomationExecutionRequest\x1a\x37.qwak.automation.v1.RegisterAutomationExecutionResponse\x12\x88\x01\n\x19UpdateAutomationExecution\x12\x34.qwak.automation.v1.UpdateAutomationExecutionRequest\x1a\x35.qwak.automation.v1.UpdateAutomationExecutionResponse\x12\x85\x01\n\x18ToggleAutomationActivity\x12\x33.qwak.automation.v1.ToggleAutomationActivityRequest\x1a\x34.qwak.automation.v1.ToggleAutomationActivityResponse\x12\x64\n\rRunAutomation\x12(.qwak.automation.v1.RunAutomationRequest\x1a).qwak.automation.v1.RunAutomationResponseB!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.automation.v1.automation_management_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY._options = None
  _LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY._serialized_options = b'8\001'
  _globals['_CREATEAUTOMATIONREQUEST']._serialized_start=162
  _globals['_CREATEAUTOMATIONREQUEST']._serialized_end=248
  _globals['_CREATEAUTOMATIONRESPONSE']._serialized_start=250
  _globals['_CREATEAUTOMATIONRESPONSE']._serialized_end=299
  _globals['_UPDATEAUTOMATIONREQUEST']._serialized_start=301
  _globals['_UPDATEAUTOMATIONREQUEST']._serialized_end=410
  _globals['_UPDATEAUTOMATIONRESPONSE']._serialized_start=412
  _globals['_UPDATEAUTOMATIONRESPONSE']._serialized_end=438
  _globals['_DELETEAUTOMATIONREQUEST']._serialized_start=440
  _globals['_DELETEAUTOMATIONREQUEST']._serialized_end=488
  _globals['_DELETEAUTOMATIONRESPONSE']._serialized_start=490
  _globals['_DELETEAUTOMATIONRESPONSE']._serialized_end=516
  _globals['_LISTAUTOMATIONSREQUEST']._serialized_start=518
  _globals['_LISTAUTOMATIONSREQUEST']._serialized_end=560
  _globals['_LISTAUTOMATIONSRESPONSE']._serialized_start=562
  _globals['_LISTAUTOMATIONSRESPONSE']._serialized_end=640
  _globals['_GETAUTOMATIONREQUEST']._serialized_start=642
  _globals['_GETAUTOMATIONREQUEST']._serialized_end=687
  _globals['_GETAUTOMATIONRESPONSE']._serialized_start=689
  _globals['_GETAUTOMATIONRESPONSE']._serialized_end=764
  _globals['_GETAUTOMATIONBYNAMEREQUEST']._serialized_start=766
  _globals['_GETAUTOMATIONBYNAMEREQUEST']._serialized_end=819
  _globals['_GETAUTOMATIONBYNAMERESPONSE']._serialized_start=821
  _globals['_GETAUTOMATIONBYNAMERESPONSE']._serialized_end=902
  _globals['_LISTAUTOMATIONEXECUTIONSREQUEST']._serialized_start=904
  _globals['_LISTAUTOMATIONEXECUTIONSREQUEST']._serialized_end=1011
  _globals['_LISTAUTOMATIONEXECUTIONSRESPONSE']._serialized_start=1013
  _globals['_LISTAUTOMATIONEXECUTIONSRESPONSE']._serialized_end=1126
  _globals['_LISTLASTAUTOMATIONEXECUTIONSREQUEST']._serialized_start=1128
  _globals['_LISTLASTAUTOMATIONEXECUTIONSREQUEST']._serialized_end=1183
  _globals['_LISTLASTAUTOMATIONEXECUTIONSRESPONSE']._serialized_start=1186
  _globals['_LISTLASTAUTOMATIONEXECUTIONSRESPONSE']._serialized_end=1504
  _globals['_LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY']._serialized_start=1380
  _globals['_LISTLASTAUTOMATIONEXECUTIONSRESPONSE_LASTAUTOMATIONEXECUTIONBYAUTOMATIONIDENTRY']._serialized_end=1504
  _globals['_REGISTERAUTOMATIONEXECUTIONREQUEST']._serialized_start=1506
  _globals['_REGISTERAUTOMATIONEXECUTIONREQUEST']._serialized_end=1587
  _globals['_REGISTERAUTOMATIONEXECUTIONRESPONSE']._serialized_start=1589
  _globals['_REGISTERAUTOMATIONEXECUTIONRESPONSE']._serialized_end=1626
  _globals['_UPDATEAUTOMATIONEXECUTIONREQUEST']._serialized_start=1628
  _globals['_UPDATEAUTOMATIONEXECUTIONREQUEST']._serialized_end=1753
  _globals['_UPDATEAUTOMATIONEXECUTIONRESPONSE']._serialized_start=1755
  _globals['_UPDATEAUTOMATIONEXECUTIONRESPONSE']._serialized_end=1790
  _globals['_TOGGLEAUTOMATIONACTIVITYREQUEST']._serialized_start=1792
  _globals['_TOGGLEAUTOMATIONACTIVITYREQUEST']._serialized_end=1868
  _globals['_TOGGLEAUTOMATIONACTIVITYRESPONSE']._serialized_start=1870
  _globals['_TOGGLEAUTOMATIONACTIVITYRESPONSE']._serialized_end=1904
  _globals['_RUNAUTOMATIONREQUEST']._serialized_start=1906
  _globals['_RUNAUTOMATIONREQUEST']._serialized_end=1951
  _globals['_RUNAUTOMATIONRESPONSE']._serialized_start=1953
  _globals['_RUNAUTOMATIONRESPONSE']._serialized_end=1976
  _globals['_AUTOMATIONMANAGEMENTSERVICE']._serialized_start=1979
  _globals['_AUTOMATIONMANAGEMENTSERVICE']._serialized_end=3477
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FileExtensionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FileExtensionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FileExtensionType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INVALID: _FileExtensionType.ValueType  # 0
    """An invalid extension type"""
    PNG: _FileExtensionType.ValueType  # 1
    """PNG extension type"""
    JPG: _FileExtensionType.ValueType  # 2
    """JPG extension type"""
    JPEG: _FileExtensionType.ValueType  # 3
    """JPEG extension type"""

class FileExtensionType(_FileExtensionType, metaclass=_FileExtensionTypeEnumTypeWrapper): ...

INVALID: FileExtensionType.ValueType  # 0
"""An invalid extension type"""
PNG: FileExtensionType.ValueType  # 1
"""PNG extension type"""
JPG: FileExtensionType.ValueType  # 2
"""JPG extension type"""
JPEG: FileExtensionType.ValueType  # 3
"""JPEG extension type"""
global___FileExtensionType = FileExtensionType

class FileTagSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUILD_ID_FIELD_NUMBER: builtins.int
    MODEL_ID_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    EXTENSION_FIELD_NUMBER: builtins.int
    EXTENSION_TYPE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """The Build id - file saved in"""
    model_id: builtins.str
    """The model id - file saved in"""
    tag: builtins.str
    """The wanted tag - file saved by"""
    extension: global___FileExtensionType.ValueType
    """The wanted extension type - file saved by"""
    extension_type: builtins.str
    environment_id: builtins.str
    """The environment the file is stored on"""
    path: builtins.str
    """The path we save the file in - it can be passed from outside in register"""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        model_id: builtins.str = ...,
        tag: builtins.str = ...,
        extension: global___FileExtensionType.ValueType = ...,
        extension_type: builtins.str = ...,
        environment_id: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "environment_id", b"environment_id", "extension", b"extension", "extension_type", b"extension_type", "model_id", b"model_id", "path", b"path", "tag", b"tag"]) -> None: ...

global___FileTagSpec = FileTagSpec

class FileTagFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_CONTAINS_FIELD_NUMBER: builtins.int
    TAG_PREFIX_FIELD_NUMBER: builtins.int
    tag_contains: builtins.str
    """Filter file tags by tag contains"""
    tag_prefix: builtins.str
    """Filter file tags by tag prefix"""
    def __init__(
        self,
        *,
        tag_contains: builtins.str = ...,
        tag_prefix: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter", "tag_contains", b"tag_contains", "tag_prefix", b"tag_prefix"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter", "tag_contains", b"tag_contains", "tag_prefix", b"tag_prefix"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["filter", b"filter"]) -> typing_extensions.Literal["tag_contains", "tag_prefix"] | None: ...

global___FileTagFilter = FileTagFilter



import json
from typing import Any

from qwak.exceptions import QwakHTTPException
from qwak.model.tools.adapters.encoders import NumpyJsonEncoder

from .base_output import BaseOutputAdapter


class JsonOutput(BaseOutputAdapter):
    def pack_user_func_return_value(self, return_result: Any) -> str:
        try:
            return json.dumps(return_result, cls=NumpyJsonEncoder, ensure_ascii=False)
        except AssertionError as e:
            QwakHTTPException(400, message=str(e))
        except Exception as e:
            QwakHTTPException(500, message=str(e))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/kube_deployment_captain/alert.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/kube_deployment_captain/alert.proto\x12\x1cqwak.kube.deployment.captain\"\x87\x01\n\rKubeAlertRule\x12\x1d\n\x15notification_channels\x18\x02 \x03(\t\x12?\n\nalert_spec\x18\x03 \x01(\x0b\x32+.qwak.kube.deployment.captain.KubeAlertSpec\x12\x16\n\x0evariation_name\x18\x04 \x01(\t\"\xc0\x02\n\rKubeAlertSpec\x12K\n\x10reducer_function\x18\x01 \x01(\x0e\x32\x31.qwak.kube.deployment.captain.KubeReducerFunction\x12G\n\x0e\x65valuator_type\x18\x02 \x01(\x0e\x32/.qwak.kube.deployment.captain.KubeEvaluatorType\x12\x1f\n\x13\x65valuator_threshold\x18\x03 \x01(\x05\x42\x02\x18\x01\x12\x19\n\x11\x65valuation_period\x18\x04 \x01(\x05\x12?\n\nalert_type\x18\x05 \x01(\x0e\x32+.qwak.kube.deployment.captain.KubeAlertType\x12\x1c\n\x14\x65valuation_threshold\x18\x06 \x01(\x02\"\xae\x01\n\x17KubeNotificationChannel\x12\x1f\n\x17notification_channel_id\x18\x01 \x01(\t\x12!\n\x19notification_channel_name\x18\x02 \x01(\t\x12O\n\x08settings\x18\x03 \x01(\x0b\x32=.qwak.kube.deployment.captain.KubeNotificationChannelSettings\"\xef\x01\n\x1fKubeNotificationChannelSettings\x12\\\n\x0eslack_settings\x18\x01 \x01(\x0b\x32\x42.qwak.kube.deployment.captain.KubeSlackNotificationChannelSettingsH\x00\x12\x62\n\x11opsgenie_settings\x18\x02 \x01(\x0b\x32\x45.qwak.kube.deployment.captain.KubeOpsgenieNotificationChannelSettingsH\x00\x42\n\n\x08settings\"H\n$KubeSlackNotificationChannelSettings\x12 \n\x18notification_channel_url\x18\x01 \x01(\t\"K\n\'KubeOpsgenieNotificationChannelSettings\x12\x0f\n\x07\x61pi_url\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t*v\n\rKubeAlertType\x12\x18\n\x14\x41LERT_TYPE_NOT_VALID\x10\x00\x12\x0e\n\nERROR_RATE\x10\x01\x12\x0e\n\nTHROUGHPUT\x10\x02\x12\x0b\n\x07LATENCY\x10\x03\x12\x0e\n\nLATENCY_90\x10\x04\x12\x0e\n\nLATENCY_95\x10\x05*\xb1\x01\n\x13KubeReducerFunction\x12\x1e\n\x1aREDUCER_FUNCTION_NOT_VALID\x10\x00\x12\x07\n\x03MIN\x10\x01\x12\x07\n\x03MAX\x10\x02\x12\x07\n\x03SUM\x10\x03\x12\t\n\x05\x43OUNT\x10\x04\x12\x08\n\x04LAST\x10\x05\x12\n\n\x06MEDIAN\x10\x06\x12\x08\n\x04\x44IFF\x10\x07\x12\x0c\n\x08\x44IFF_ABS\x10\x08\x12\x10\n\x0cPERCENT_DIFF\x10\t\x12\x14\n\x10PERCENT_DIFF_ABS\x10\n*M\n\x11KubeEvaluatorType\x12\x1c\n\x18\x45VALUATOR_TYPE_NOT_VALID\x10\x00\x12\x0c\n\x08IS_ABOVE\x10\x01\x12\x0c\n\x08IS_BELOW\x10\x02\x42+\n\'com.qwak.ai.kube.deployment.captain.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.kube_deployment_captain.alert_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'com.qwak.ai.kube.deployment.captain.apiP\001'
  _KUBEALERTSPEC.fields_by_name['evaluator_threshold']._options = None
  _KUBEALERTSPEC.fields_by_name['evaluator_threshold']._serialized_options = b'\030\001'
  _globals['_KUBEALERTTYPE']._serialized_start=1105
  _globals['_KUBEALERTTYPE']._serialized_end=1223
  _globals['_KUBEREDUCERFUNCTION']._serialized_start=1226
  _globals['_KUBEREDUCERFUNCTION']._serialized_end=1403
  _globals['_KUBEEVALUATORTYPE']._serialized_start=1405
  _globals['_KUBEEVALUATORTYPE']._serialized_end=1482
  _globals['_KUBEALERTRULE']._serialized_start=75
  _globals['_KUBEALERTRULE']._serialized_end=210
  _globals['_KUBEALERTSPEC']._serialized_start=213
  _globals['_KUBEALERTSPEC']._serialized_end=533
  _globals['_KUBENOTIFICATIONCHANNEL']._serialized_start=536
  _globals['_KUBENOTIFICATIONCHANNEL']._serialized_end=710
  _globals['_KUBENOTIFICATIONCHANNELSETTINGS']._serialized_start=713
  _globals['_KUBENOTIFICATIONCHANNELSETTINGS']._serialized_end=952
  _globals['_KUBESLACKNOTIFICATIONCHANNELSETTINGS']._serialized_start=954
  _globals['_KUBESLACKNOTIFICATIONCHANNELSETTINGS']._serialized_end=1026
  _globals['_KUBEOPSGENIENOTIFICATIONCHANNELSETTINGS']._serialized_start=1028
  _globals['_KUBEOPSGENIENOTIFICATIONCHANNELSETTINGS']._serialized_end=1103
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/offline/serving/v1/population.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(qwak/offline/serving/v1/population.proto\x12%qwak.feature.store.offline.serving.v1\"\x1d\n\x1bPopulationFileUploadUrlType\"w\n\x0fTimedPopulation\x12\x1d\n\x15timestamp_column_name\x18\x01 \x01(\t\x12\x45\n\npopulation\x18\x02 \x01(\x0b\x32\x31.qwak.feature.store.offline.serving.v1.Population\"f\n\nPopulation\x12P\n\x0fpopulation_file\x18\x01 \x01(\x0b\x32\x35.qwak.feature.store.offline.serving.v1.PopulationFileH\x00\x42\x06\n\x04type\"\x81\x01\n\x0ePopulationFile\x12\x10\n\x08\x66ile_url\x18\x01 \x01(\t\x12S\n\x11\x61rrow_schema_json\x18\x02 \x01(\x0b\x32\x36.qwak.feature.store.offline.serving.v1.ArrowSchemaJsonH\x00\x42\x08\n\x06schema\"!\n\x0f\x41rrowSchemaJson\x12\x0e\n\x06schema\x18\x01 \x01(\tB&\n\"com.qwak.ai.offline.serving.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.offline.serving.v1.population_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.qwak.ai.offline.serving.api.v1P\001'
  _globals['_POPULATIONFILEUPLOADURLTYPE']._serialized_start=83
  _globals['_POPULATIONFILEUPLOADURLTYPE']._serialized_end=112
  _globals['_TIMEDPOPULATION']._serialized_start=114
  _globals['_TIMEDPOPULATION']._serialized_end=233
  _globals['_POPULATION']._serialized_start=235
  _globals['_POPULATION']._serialized_end=337
  _globals['_POPULATIONFILE']._serialized_start=340
  _globals['_POPULATIONFILE']._serialized_end=469
  _globals['_ARROWSCHEMAJSON']._serialized_start=471
  _globals['_ARROWSCHEMAJSON']._serialized_end=504
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/fitness_service/fitness_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.fitness_service import fitness_pb2 as qwak_dot_fitness__service_dot_fitness__pb2
from _qwak_proto.qwak.fitness_service import status_pb2 as qwak_dot_fitness__service_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*qwak/fitness_service/fitness_service.proto\x12\x14qwak.fitness.service\x1a\"qwak/fitness_service/fitness.proto\x1a!qwak/fitness_service/status.proto\"H\n\x11\x42uildModelRequest\x12\x33\n\nbuild_spec\x18\x01 \x01(\x0b\x32\x1f.qwak.fitness.service.BuildSpec\"\x14\n\x12\x42uildModelResponse\"+\n\x17\x43\x61ncelBuildModelRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"\x1a\n\x18\x43\x61ncelBuildModelResponse\"2\n\x1eGetRemoteBuildingStatusRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"]\n\x1fGetRemoteBuildingStatusResponse\x12:\n\x06status\x18\x01 \x01(\x0b\x32*.qwak.fitness.service.RemoteBuildingStatus\"4\n CleanRemoteBuildResourcesRequest\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\"#\n!CleanRemoteBuildResourcesResponse2\xfc\x03\n\x0e\x46itnessService\x12_\n\nBuildModel\x12\'.qwak.fitness.service.BuildModelRequest\x1a(.qwak.fitness.service.BuildModelResponse\x12q\n\x10\x43\x61ncelBuildModel\x12-.qwak.fitness.service.CancelBuildModelRequest\x1a..qwak.fitness.service.CancelBuildModelResponse\x12\x86\x01\n\x17GetRemoteBuildingStatus\x12\x34.qwak.fitness.service.GetRemoteBuildingStatusRequest\x1a\x35.qwak.fitness.service.GetRemoteBuildingStatusResponse\x12\x8c\x01\n\x19\x43leanRemoteBuildResources\x12\x36.qwak.fitness.service.CleanRemoteBuildResourcesRequest\x1a\x37.qwak.fitness.service.CleanRemoteBuildResourcesResponseB#\n\x1f\x63om.qwak.ai.fitness.service.apiP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.fitness_service.fitness_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037com.qwak.ai.fitness.service.apiP\001'
  _globals['_BUILDMODELREQUEST']._serialized_start=139
  _globals['_BUILDMODELREQUEST']._serialized_end=211
  _globals['_BUILDMODELRESPONSE']._serialized_start=213
  _globals['_BUILDMODELRESPONSE']._serialized_end=233
  _globals['_CANCELBUILDMODELREQUEST']._serialized_start=235
  _globals['_CANCELBUILDMODELREQUEST']._serialized_end=278
  _globals['_CANCELBUILDMODELRESPONSE']._serialized_start=280
  _globals['_CANCELBUILDMODELRESPONSE']._serialized_end=306
  _globals['_GETREMOTEBUILDINGSTATUSREQUEST']._serialized_start=308
  _globals['_GETREMOTEBUILDINGSTATUSREQUEST']._serialized_end=358
  _globals['_GETREMOTEBUILDINGSTATUSRESPONSE']._serialized_start=360
  _globals['_GETREMOTEBUILDINGSTATUSRESPONSE']._serialized_end=453
  _globals['_CLEANREMOTEBUILDRESOURCESREQUEST']._serialized_start=455
  _globals['_CLEANREMOTEBUILDRESOURCESREQUEST']._serialized_end=507
  _globals['_CLEANREMOTEBUILDRESOURCESRESPONSE']._serialized_start=509
  _globals['_CLEANREMOTEBUILDRESOURCESRESPONSE']._serialized_end=544
  _globals['_FITNESSSERVICE']._serialized_start=547
  _globals['_FITNESSSERVICE']._serialized_end=1055
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/integration/slack_app_integration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,qwak/integration/slack_app_integration.proto\x12\x1bqwak.integration.management\"\x9f\x02\n\x13SlackAppIntegration\x12\\\n\x1f\x65ncrypted_slack_app_auth_config\x18\x01 \x01(\x0b\x32/.qwak.integration.management.SlackAppAuthConfigB\x02\x18\x01\x12I\n\x12slack_app_settings\x18\x02 \x01(\x0b\x32-.qwak.integration.management.SlackAppSettings\x12W\n\x13slack_system_secret\x18\x03 \x01(\x0b\x32\x38.qwak.integration.management.SlackSystemSecretDescriptorH\x00\x42\x06\n\x04\x61uth\"\x8e\x01\n\x17SlackAppIntegrationSpec\x12\x64\n\x1fslack_app_temporary_credentials\x18\x01 \x01(\x0b\x32\x39.qwak.integration.management.SlackAppTemporaryCredentialsH\x00\x42\r\n\x0b\x63redentials\"Q\n\x1cSlackAppTemporaryCredentials\x12\r\n\x05state\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x14\n\x0credirect_uri\x18\x03 \x01(\t\"\xa6\x01\n\x10SlackAppSettings\x12:\n\nslack_team\x18\x01 \x01(\x0b\x32&.qwak.integration.management.SlackTeam\x12H\n\x10slack_enterprise\x18\x02 \x01(\x0b\x32,.qwak.integration.management.SlackEnterpriseH\x00\x42\x0c\n\nenterprise\",\n\x12SlackAppAuthConfig\x12\x16\n\x0e\x62ot_user_token\x18\x01 \x01(\t\"V\n\x1bSlackSystemSecretDescriptor\x12\x13\n\x0bsecret_name\x18\x01 \x01(\t\x12\x0f\n\x07url_key\x18\x02 \x01(\t\x12\x11\n\ttoken_key\x18\x03 \x01(\t\"\x18\n\x16SlackAppValidationSpec\"\x1c\n\x1aSlackAppIntegrationOptions\"%\n\tSlackTeam\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"+\n\x0fSlackEnterprise\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\tBH\n&com.qwak.ai.management.integration.apiP\x01Z\x1cqwak/integration;integrationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.integration.slack_app_integration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.qwak.ai.management.integration.apiP\001Z\034qwak/integration;integration'
  _SLACKAPPINTEGRATION.fields_by_name['encrypted_slack_app_auth_config']._options = None
  _SLACKAPPINTEGRATION.fields_by_name['encrypted_slack_app_auth_config']._serialized_options = b'\030\001'
  _globals['_SLACKAPPINTEGRATION']._serialized_start=78
  _globals['_SLACKAPPINTEGRATION']._serialized_end=365
  _globals['_SLACKAPPINTEGRATIONSPEC']._serialized_start=368
  _globals['_SLACKAPPINTEGRATIONSPEC']._serialized_end=510
  _globals['_SLACKAPPTEMPORARYCREDENTIALS']._serialized_start=512
  _globals['_SLACKAPPTEMPORARYCREDENTIALS']._serialized_end=593
  _globals['_SLACKAPPSETTINGS']._serialized_start=596
  _globals['_SLACKAPPSETTINGS']._serialized_end=762
  _globals['_SLACKAPPAUTHCONFIG']._serialized_start=764
  _globals['_SLACKAPPAUTHCONFIG']._serialized_end=808
  _globals['_SLACKSYSTEMSECRETDESCRIPTOR']._serialized_start=810
  _globals['_SLACKSYSTEMSECRETDESCRIPTOR']._serialized_end=896
  _globals['_SLACKAPPVALIDATIONSPEC']._serialized_start=898
  _globals['_SLACKAPPVALIDATIONSPEC']._serialized_end=922
  _globals['_SLACKAPPINTEGRATIONOPTIONS']._serialized_start=924
  _globals['_SLACKAPPINTEGRATIONOPTIONS']._serialized_end=952
  _globals['_SLACKTEAM']._serialized_start=954
  _globals['_SLACKTEAM']._serialized_end=991
  _globals['_SLACKENTERPRISE']._serialized_start=993
  _globals['_SLACKENTERPRISE']._serialized_end=1036
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/workspace/workspace.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.user_application.common.v0 import resources_pb2 as qwak_dot_user__application_dot_common_dot_v0_dot_resources__pb2
from _qwak_proto.qwak.user_application.v0 import user_application_pb2 as qwak_dot_user__application_dot_v0_dot_user__application__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eqwak/workspace/workspace.proto\x12\x19qwak.workspace.management\x1a\x1fgoogle/protobuf/timestamp.proto\x1a/qwak/user_application/common/v0/resources.proto\x1a/qwak/user_application/v0/user_application.proto\"\xc4\x04\n\tWorkspace\x12\x16\n\x0eworkspace_name\x18\x01 \x01(\t\x12`\n\x1c\x63lient_pod_compute_resources\x18\x02 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12\x10\n\x08image_id\x18\x03 \x01(\t\x12\x17\n\x0f\x63reator_user_id\x18\x04 \x01(\t\x12\x1b\n\x13last_update_user_id\x18\x05 \x01(\t\x12/\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10last_update_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0cworkspace_id\x18\t \x01(\t\x12\x0c\n\x04tags\x18\n \x03(\t\x12N\n\x1aworkspace_deployment_state\x18\x0b \x01(\x0e\x32*.qwak.workspace.management.DeploymentState\x12\x44\n\x10workspace_status\x18\x0c \x01(\x0e\x32*.qwak.workspace.management.WorkspaceStatus\x12\x15\n\rerror_message\x18\r \x01(\t\x12\x12\n\nimage_name\x18\x0e \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x0f \x01(\t\x12\x11\n\tbuild_ids\x18\x10 \x03(\t\"\xd3\x01\n\rWorkspaceSpec\x12\x16\n\x0eworkspace_name\x18\x01 \x01(\t\x12`\n\x1c\x63lient_pod_compute_resources\x18\x02 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12\x10\n\x08image_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x16\n\x0e\x65nvironment_id\x18\x05 \x01(\t\x12\x10\n\x08\x62uild_id\x18\x06 \x01(\t\"\x9d\x02\n\x1bWorkspaceDeploymentSnapshot\x12\x16\n\x0eworkspace_name\x18\x01 \x01(\t\x12\x14\n\x0cworkspace_id\x18\x02 \x01(\t\x12\x36\n\ndeployment\x18\x03 \x01(\x0b\x32\x1e.qwak.user_application.v0.SpecB\x02\x18\x01\x12\x34\n\x08replicas\x18\x04 \x03(\x0b\x32\x1e.qwak.user_application.v0.SpecB\x02\x18\x01\x12,\n\x04pods\x18\x05 \x03(\x0b\x32\x1e.qwak.user_application.v0.Spec\x12\x34\n\x0cstateful_set\x18\x06 \x01(\x0b\x32\x1e.qwak.user_application.v0.Spec\"\xb1\x01\n$UpdateWorkspaceStatusFromEdgeDetails\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x02 \x01(\t\x12]\n\x1dworkspace_deployment_snapshot\x18\x03 \x03(\x0b\x32\x36.qwak.workspace.management.WorkspaceDeploymentSnapshot\"Y\n\x0eWorkspaceImage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12-\n\x04type\x18\x03 \x01(\x0e\x32\x1f.qwak.workspace.management.Type\"\xfb\x01\n\x17\x44\x65\x66\x61ultWorkspaceDetails\x12Y\n\x15\x63pu_compute_resources\x18\x01 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12Y\n\x15gpu_compute_resources\x18\x02 \x01(\x0b\x32:.qwak.user_application.common.v0.ClientPodComputeResources\x12\x14\n\x0c\x63pu_image_id\x18\x03 \x01(\t\x12\x14\n\x0cgpu_image_id\x18\x04 \x01(\t*\x18\n\x04Type\x12\x07\n\x03\x43PU\x10\x00\x12\x07\n\x03GPU\x10\x01*\xaa\x01\n\x0fWorkspaceStatus\x12\x1c\n\x18WORKSPACE_STATUS_UNKNOWN\x10\x00\x12!\n\x1dWORKSPACE_STATUS_INITIALIZING\x10\x01\x12\x1c\n\x18WORKSPACE_STATUS_STARTED\x10\x02\x12\x1c\n\x18WORKSPACE_STATUS_STOPPED\x10\x03\x12\x1a\n\x16WORKSPACE_STATUS_ERROR\x10\x04*\xe0\x07\n\x0f\x44\x65ploymentState\x12\x1c\n\x18\x44\x45PLOYMENT_STATE_UNKNOWN\x10\x00\x12)\n%DEPLOYMENT_STATE_INITIATING_WORKSPACE\x10\x01\x12\x30\n,DEPLOYMENT_STATE_DEPLOYING_REQUEST_WORKSPACE\x10\x02\x12\x33\n/DEPLOYMENT_STATE_FAILED_EVENT_COMMAND_WORKSPACE\x10\x03\x12)\n%DEPLOYMENT_STATE_DELETION_IN_PROGRESS\x10\x04\x12\x33\n/DEPLOYMENT_STATE_RESUME_EVENT_COMMAND_WORKSPACE\x10\x05\x12\x31\n-DEPLOYMENT_STATE_STOP_EVENT_COMMAND_WORKSPACE\x10\x06\x12(\n$DEPLOYMENT_STATE_STOPPING_DEPLOYMENT\x10\x07\x12\'\n#DEPLOYMENT_STATE_STOPPED_DEPLOYMENT\x10\x08\x12 \n\x1c\x44\x45PLOYMENT_STATE_INITIALIZED\x10\t\x12\x1a\n\x16\x44\x45PLOYMENT_STATE_READY\x10\n\x12%\n!DEPLOYMENT_STATE_CONTAINERS_READY\x10\x0b\x12\"\n\x1e\x44\x45PLOYMENT_STATE_POD_SCHEDULED\x10\x0c\x12\"\n\x1e\x44\x45PLOYMENT_STATE_UNSCHEDULABLE\x10\r\x12)\n%DEPLOYMENT_STATE_CONTAINERS_NOT_READY\x10\x0e\x12\x1e\n\x1a\x44\x45PLOYMENT_STATE_AVAILABLE\x10\x0f\x12 \n\x1c\x44\x45PLOYMENT_STATE_PROGRESSING\x10\x10\x12$\n DEPLOYMENT_STATE_REPLICA_FAILURE\x10\x11\x12/\n+DEPLOYMENT_STATE_MINIMUM_REPLICAS_AVAILABLE\x10\x12\x12\x31\n-DEPLOYMENT_STATE_MINIMUM_REPLICAS_UNAVAILABLE\x10\x13\x12\x30\n,DEPLOYMENT_STATE_PROGRESS_DEAD_LINE_EXCEEDED\x10\x14\x12.\n*DEPLOYMENT_STATE_NEW_REPLICA_SET_AVAILABLE\x10\x15\x12\x31\n-DEPLOYMENT_STATE_IDLE_TIME_STOPPED_DEPLOYMENT\x10\x16\x42\x42\n$com.qwak.ai.management.workspace.apiP\x01Z\x18qwak/workspace;workspaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.workspace.workspace_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.qwak.ai.management.workspace.apiP\001Z\030qwak/workspace;workspace'
  _WORKSPACEDEPLOYMENTSNAPSHOT.fields_by_name['deployment']._options = None
  _WORKSPACEDEPLOYMENTSNAPSHOT.fields_by_name['deployment']._serialized_options = b'\030\001'
  _WORKSPACEDEPLOYMENTSNAPSHOT.fields_by_name['replicas']._options = None
  _WORKSPACEDEPLOYMENTSNAPSHOT.fields_by_name['replicas']._serialized_options = b'\030\001'
  _globals['_TYPE']._serialized_start=1802
  _globals['_TYPE']._serialized_end=1826
  _globals['_WORKSPACESTATUS']._serialized_start=1829
  _globals['_WORKSPACESTATUS']._serialized_end=1999
  _globals['_DEPLOYMENTSTATE']._serialized_start=2002
  _globals['_DEPLOYMENTSTATE']._serialized_end=2994
  _globals['_WORKSPACE']._serialized_start=193
  _globals['_WORKSPACE']._serialized_end=773
  _globals['_WORKSPACESPEC']._serialized_start=776
  _globals['_WORKSPACESPEC']._serialized_end=987
  _globals['_WORKSPACEDEPLOYMENTSNAPSHOT']._serialized_start=990
  _globals['_WORKSPACEDEPLOYMENTSNAPSHOT']._serialized_end=1275
  _globals['_UPDATEWORKSPACESTATUSFROMEDGEDETAILS']._serialized_start=1278
  _globals['_UPDATEWORKSPACESTATUSFROMEDGEDETAILS']._serialized_end=1455
  _globals['_WORKSPACEIMAGE']._serialized_start=1457
  _globals['_WORKSPACEIMAGE']._serialized_end=1546
  _globals['_DEFAULTWORKSPACEDETAILS']._serialized_start=1549
  _globals['_DEFAULTWORKSPACEDETAILS']._serialized_end=1800
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/state/spark_execution_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3qwak/execution/v1/state/spark_execution_state.proto\x12%qwak.feature.store.execution.v1.state\"\x8f\x03\n\x13SparkExecutionState\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\x12S\n\x16spark_application_type\x18\x02 \x01(\x0e\x32\x33.qwak.feature.store.execution.v1.state.SparkAppType\x12O\n\x0fspark_app_state\x18\x03 \x01(\x0b\x32\x34.qwak.feature.store.execution.v1.state.SparkAppStateH\x00\x12l\n\x11\x61pplicationLabels\x18\x04 \x03(\x0b\x32Q.qwak.feature.store.execution.v1.state.SparkExecutionState.ApplicationLabelsEntry\x1a\x38\n\x16\x41pplicationLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x12\n\x10state_descriptor\"t\n\rSparkAppState\x12L\n\nstate_type\x18\x01 \x01(\x0e\x32\x38.qwak.feature.store.execution.v1.state.SparkAppStateType\x12\x15\n\rerror_message\x18\x02 \x01(\t*\xdf\x03\n\x0cSparkAppType\x12\x1a\n\x16SPARK_APP_TYPE_INVALID\x10\x00\x12\"\n\x1eSPARK_APP_TYPE_BATCH_INGESTION\x10\x01\x12!\n\x1dSPARK_APP_TYPE_BATCH_BACKFILL\x10\x02\x12!\n\x1dSPARK_APP_TYPE_BATCH_DELETION\x10\x03\x12#\n\x1fSPARK_APP_TYPE_STREAMING_ONLINE\x10\x04\x12$\n SPARK_APP_TYPE_STREAMING_OFFLINE\x10\x05\x12%\n!SPARK_APP_TYPE_STREAMING_BACKFILL\x10\x06\x12%\n!SPARK_APP_TYPE_STREAMING_DELETION\x10\x07\x12*\n&SPARK_APP_TYPE_STREAMING_AGGR_ROWLEVEL\x10\x08\x12,\n(SPARK_APP_TYPE_STREAMING_AGGR_COMPACTION\x10\t\x12*\n&SPARK_APP_TYPE_STREAMING_AGGR_BACKFILL\x10\n\x12*\n&SPARK_APP_TYPE_STREAMING_AGGR_DELETION\x10\x0b*\x88\x03\n\x11SparkAppStateType\x12\x1b\n\x17SPARK_APP_STATE_INVALID\x10\x00\x12\x1d\n\x19SPARK_APP_STATE_COMPLETED\x10\x01\x12\x1a\n\x16SPARK_APP_STATE_FAILED\x10\x02\x12%\n!SPARK_APP_STATE_SUBMISSION_FAILED\x10\x03\x12\x1b\n\x17SPARK_APP_STATE_FAILING\x10\x04\x12 \n\x1cSPARK_APP_STATE_INVALIDATING\x10\x05\x12\x19\n\x15SPARK_APP_STATE_EMPTY\x10\x06\x12!\n\x1dSPARK_APP_STATE_PENDING_RERUN\x10\x07\x12\x1b\n\x17SPARK_APP_STATE_RUNNING\x10\x08\x12\x1d\n\x19SPARK_APP_STATE_SUBMITTED\x10\t\x12\x1e\n\x1aSPARK_APP_STATE_SUCCEEDING\x10\n\x12\x1b\n\x17SPARK_APP_STATE_UNKNOWN\x10\x0b\x42`\n+com.qwak.ai.features.execution.api.v1.stateP\x01Z/qwak/execution_management/state;execution_stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.state.spark_execution_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.qwak.ai.features.execution.api.v1.stateP\001Z/qwak/execution_management/state;execution_state'
  _SPARKEXECUTIONSTATE_APPLICATIONLABELSENTRY._options = None
  _SPARKEXECUTIONSTATE_APPLICATIONLABELSENTRY._serialized_options = b'8\001'
  _globals['_SPARKAPPTYPE']._serialized_start=615
  _globals['_SPARKAPPTYPE']._serialized_end=1094
  _globals['_SPARKAPPSTATETYPE']._serialized_start=1097
  _globals['_SPARKAPPSTATETYPE']._serialized_end=1489
  _globals['_SPARKEXECUTIONSTATE']._serialized_start=95
  _globals['_SPARKEXECUTIONSTATE']._serialized_end=494
  _globals['_SPARKEXECUTIONSTATE_APPLICATIONLABELSENTRY']._serialized_start=418
  _globals['_SPARKEXECUTIONSTATE_APPLICATIONLABELSENTRY']._serialized_end=474
  _globals['_SPARKAPPSTATE']._serialized_start=496
  _globals['_SPARKAPPSTATE']._serialized_end=612
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/runtime_configuration/v0/external/victoriametrics_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0.external import prometheus_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_external_dot_prometheus__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRqwak/administration/runtime_configuration/v0/external/victoriametrics_config.proto\x12Lqwak.administration.runtime_configuration.v0.external.victoriametrics_config\x1aMqwak/administration/runtime_configuration/v0/external/prometheus_config.proto\"\x9c\x01\n\x1cVictoriaMetricsConfiguration\x12n\n\x06promxy\x18\x01 \x01(\x0b\x32\\.qwak.administration.runtime_configuration.v0.external.prometheus_config.PromxyConfigurationH\x00\x42\x0c\n\nproxy_typeB\xfe\x01\nEcom.jfrog.ml.runtime_configuration.v0.external.victoriametrics_configP\x01Z\xb2\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_externalb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.runtime_configuration.v0.external.victoriametrics_config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\nEcom.jfrog.ml.runtime_configuration.v0.external.victoriametrics_configP\001Z\262\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/runtime_configuration/v0/external;runtime_configuration_v0_external'
  _globals['_VICTORIAMETRICSCONFIGURATION']._serialized_start=244
  _globals['_VICTORIAMETRICSCONFIGURATION']._serialized_end=400
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.deployment.deployment_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ModelDeploymentNotification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    BRANCH_ID_FIELD_NUMBER: builtins.int
    BUILD_ID_FIELD_NUMBER: builtins.int
    HOSTING_SERVICE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DEPLOYMENT_ID_FIELD_NUMBER: builtins.int
    FAILURE_REASON_CODE_FIELD_NUMBER: builtins.int
    FAILURE_TECHNICAL_DETAILS_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    """Model name, which will be used as a routing key for the model"""
    branch_id: builtins.str
    """Branch ID to deploy the model under"""
    build_id: builtins.str
    """Build ID (which must be successful) to deploy"""
    @property
    def hosting_service(self) -> qwak.deployment.deployment_pb2.HostingService:
        """Downstream hosting service that will serve the Qwak model"""
    status: qwak.deployment.deployment_pb2.ModelDeploymentStatus.ValueType
    """The deployment status"""
    deployment_id: builtins.str
    """The deployment ID"""
    failure_reason_code: builtins.str
    """The failure reason - Machine-readable, UpperCamelCase text"""
    failure_technical_details: builtins.str
    """The message describing the reason"""
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
        branch_id: builtins.str = ...,
        build_id: builtins.str = ...,
        hosting_service: qwak.deployment.deployment_pb2.HostingService | None = ...,
        status: qwak.deployment.deployment_pb2.ModelDeploymentStatus.ValueType = ...,
        deployment_id: builtins.str = ...,
        failure_reason_code: builtins.str = ...,
        failure_technical_details: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["hosting_service", b"hosting_service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_id", b"branch_id", "build_id", b"build_id", "deployment_id", b"deployment_id", "failure_reason_code", b"failure_reason_code", "failure_technical_details", b"failure_technical_details", "hosting_service", b"hosting_service", "model_name", b"model_name", "status", b"status"]) -> None: ...

global___ModelDeploymentNotification = ModelDeploymentNotification



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/traffic/v1/traffic_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.traffic.v1 import traffic_pb2 as qwak_dot_traffic_dot_v1_dot_traffic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!qwak/traffic/v1/traffic_api.proto\x12\x0fqwak.traffic.v1\x1a\x1dqwak/traffic/v1/traffic.proto\"e\n\x1eResetAndSetTrafficStateRequest\x12\x43\n\x15multiple_http_traffic\x18\x01 \x01(\x0b\x32$.qwak.traffic.v1.MultipleHttpTraffic\"!\n\x1fResetAndSetTrafficStateResponse\"\x8f\x01\n\x1a\x41pplyGroupedTrafficRequest\x12\x45\n\x15multiple_http_traffic\x18\x01 \x01(\x0b\x32$.qwak.traffic.v1.MultipleHttpTrafficH\x00\x12\x10\n\x08group_id\x18\x02 \x01(\t\x12\r\n\x05hosts\x18\x03 \x03(\tB\t\n\x07traffic\"\x1d\n\x1b\x41pplyGroupedTrafficResponse\"~\n\x15\x43reateEndpointRequest\x12\x10\n\x08group_id\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12\x11\n\tvariation\x18\x03 \x01(\t\x12\x1f\n\x17http_request_timeout_ms\x18\x04 \x01(\x05\x12\r\n\x05hosts\x18\x05 \x03(\t\"\x18\n\x16\x43reateEndpointResponse\")\n\x15\x44\x65leteEndpointRequest\x12\x10\n\x08group_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteEndpointResponse2\xc2\x03\n\nTrafficAPI\x12|\n\x17ResetAndSetTrafficState\x12/.qwak.traffic.v1.ResetAndSetTrafficStateRequest\x1a\x30.qwak.traffic.v1.ResetAndSetTrafficStateResponse\x12p\n\x13\x41pplyGroupedTraffic\x12+.qwak.traffic.v1.ApplyGroupedTrafficRequest\x1a,.qwak.traffic.v1.ApplyGroupedTrafficResponse\x12\x61\n\x0e\x43reateEndpoint\x12&.qwak.traffic.v1.CreateEndpointRequest\x1a\'.qwak.traffic.v1.CreateEndpointResponse\x12\x61\n\x0e\x44\x65leteEndpoint\x12&.qwak.traffic.v1.DeleteEndpointRequest\x1a\'.qwak.traffic.v1.DeleteEndpointResponseB\x17\n\x13\x63om.qwak.traffic.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.traffic.v1.traffic_api_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.qwak.traffic.v1P\001'
  _globals['_RESETANDSETTRAFFICSTATEREQUEST']._serialized_start=85
  _globals['_RESETANDSETTRAFFICSTATEREQUEST']._serialized_end=186
  _globals['_RESETANDSETTRAFFICSTATERESPONSE']._serialized_start=188
  _globals['_RESETANDSETTRAFFICSTATERESPONSE']._serialized_end=221
  _globals['_APPLYGROUPEDTRAFFICREQUEST']._serialized_start=224
  _globals['_APPLYGROUPEDTRAFFICREQUEST']._serialized_end=367
  _globals['_APPLYGROUPEDTRAFFICRESPONSE']._serialized_start=369
  _globals['_APPLYGROUPEDTRAFFICRESPONSE']._serialized_end=398
  _globals['_CREATEENDPOINTREQUEST']._serialized_start=400
  _globals['_CREATEENDPOINTREQUEST']._serialized_end=526
  _globals['_CREATEENDPOINTRESPONSE']._serialized_start=528
  _globals['_CREATEENDPOINTRESPONSE']._serialized_end=552
  _globals['_DELETEENDPOINTREQUEST']._serialized_start=554
  _globals['_DELETEENDPOINTREQUEST']._serialized_end=595
  _globals['_DELETEENDPOINTRESPONSE']._serialized_start=597
  _globals['_DELETEENDPOINTRESPONSE']._serialized_end=621
  _globals['_TRAFFICAPI']._serialized_start=624
  _globals['_TRAFFICAPI']._serialized_end=1074
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.admiral.user_application_instance.v0 import user_application_instance_service_pb2 as qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2


class UserApplicationInstanceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateUserApplicationInstance = channel.unary_unary(
                '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/CreateUserApplicationInstance',
                request_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceResponse.FromString,
                )
        self.UpdateUserApplicationInstanceSpec = channel.unary_unary(
                '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/UpdateUserApplicationInstanceSpec',
                request_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecResponse.FromString,
                )
        self.GetUserApplicationInstance = channel.unary_unary(
                '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/GetUserApplicationInstance',
                request_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceResponse.FromString,
                )
        self.DeleteUserApplicationInstance = channel.unary_unary(
                '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/DeleteUserApplicationInstance',
                request_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceRequest.SerializeToString,
                response_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceResponse.FromString,
                )


class UserApplicationInstanceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateUserApplicationInstance(self, request, context):
        """Create new user application instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserApplicationInstanceSpec(self, request, context):
        """Update a user application instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserApplicationInstance(self, request, context):
        """Get a user application instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserApplicationInstance(self, request, context):
        """Delete a user application instance
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserApplicationInstanceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateUserApplicationInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateUserApplicationInstance,
                    request_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceResponse.SerializeToString,
            ),
            'UpdateUserApplicationInstanceSpec': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserApplicationInstanceSpec,
                    request_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecResponse.SerializeToString,
            ),
            'GetUserApplicationInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserApplicationInstance,
                    request_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceResponse.SerializeToString,
            ),
            'DeleteUserApplicationInstance': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserApplicationInstance,
                    request_deserializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceRequest.FromString,
                    response_serializer=qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.admiral.user_app_instance.v0.UserApplicationInstanceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserApplicationInstanceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateUserApplicationInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/CreateUserApplicationInstance',
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceRequest.SerializeToString,
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.CreateUserApplicationInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserApplicationInstanceSpec(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/UpdateUserApplicationInstanceSpec',
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecRequest.SerializeToString,
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.UpdateUserApplicationInstanceSpecResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserApplicationInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/GetUserApplicationInstance',
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceRequest.SerializeToString,
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.GetUserApplicationInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserApplicationInstance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.admiral.user_app_instance.v0.UserApplicationInstanceService/DeleteUserApplicationInstance',
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceRequest.SerializeToString,
            qwak_dot_admiral_dot_user__application__instance_dot_v0_dot_user__application__instance__service__pb2.DeleteUserApplicationInstanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from abc import ABC, abstractmethod
from dataclasses import dataclass

from _qwak_proto.qwak.feature_store.sources.batch_pb2 import (
    AwsAssumeRoleAuthentication as ProtoAwsAssumeRoleAuthentication,
    AwsCredentialsAuthentication as ProtoAwsCredentialsAuthentication,
)


class AwsAuthentication(ABC):
    @abstractmethod
    def _to_proto(self):
        pass


@dataclass
class AwsAssumeRoleAuthentication(AwsAuthentication):
    role_arn: str

    def _to_proto(self):
        return ProtoAwsAssumeRoleAuthentication(role_arn=self.role_arn)


@dataclass
class AwsCredentialsAuthentication(AwsAuthentication):
    access_key_secret_name: str
    secret_key_secret_name: str

    def _to_proto(self):
        return ProtoAwsCredentialsAuthentication(
            access_key_secret_name=self.access_key_secret_name,
            secret_key_secret_name=self.secret_key_secret_name,
        )



import os
from dataclasses import dataclass
from typing import Optional, Sequence, Tuple

from _qwak_proto.qwak.administration.account.v1.account_pb2 import AccountType
from _qwak_proto.qwak.ecosystem.v0.ecosystem_pb2 import AuthenticatedUnifiedUserContext
from qwak.exceptions import QwakException

_ONLINE_SERVING_ENDPOINT_OVERRIDE_ENV_VAR = "ONLINE_SERVING_ENDPOINT"
_default_endpoint_url = "fs-serving-webapp.qwak.svc.cluster.local:6577/com.qwak.ai.feature.store.serving.api.ServingService"


@dataclass
class EndpointConfig:
    endpoint_url: str
    metadata: Optional[Sequence[Tuple[str, str]]]
    enable_ssl: Optional[bool]


def _get_direct_endpoint(
    user_context: AuthenticatedUnifiedUserContext,
) -> EndpointConfig:
    endpoint_url: str = os.environ.get(
        _ONLINE_SERVING_ENDPOINT_OVERRIDE_ENV_VAR, _default_endpoint_url
    )
    # As of time of writing, feature-store is single env!
    metadata = (
        ("qwak-user-id", user_context.user_id),
        ("qwak-account-id", user_context.account_details.id),
        ("qwak-environment-id", user_context.account_details.default_environment_id),
    )

    return EndpointConfig(
        endpoint_url=endpoint_url, metadata=metadata, enable_ssl=False
    )


def _get_edge_services_endpoint(
    user_context: AuthenticatedUnifiedUserContext,
) -> EndpointConfig:
    environment_id: str = user_context.account_details.default_environment_id

    if environment_id not in user_context.account_details.environment_by_id:
        raise QwakException(
            f"Configuration for environment [{environment_id}] was not found"
        )

    endpoint_url: str = user_context.account_details.environment_by_id[
        environment_id
    ].configuration.edge_services_url

    return EndpointConfig(endpoint_url=endpoint_url, metadata=None, enable_ssl=None)


def get_config_by_account_type(
    user_context: AuthenticatedUnifiedUserContext,
) -> EndpointConfig:
    user_account_type: AccountType = user_context.account_details.type

    if user_account_type == AccountType.HYBRID and "K8S_POD_NAME" in os.environ:
        return _get_direct_endpoint(user_context)
    else:
        return _get_edge_services_endpoint(user_context)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/automation/v1/notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%qwak/automation/v1/notification.proto\x12\x12qwak.automation.v1\"\xa9\x01\n\x0cNotification\x12L\n\x17post_slack_notification\x18\x01 \x01(\x0b\x32).qwak.automation.v1.PostSlackNotificationH\x00\x12;\n\x0e\x63ustom_webhook\x18\x02 \x01(\x0b\x32!.qwak.automation.v1.CustomWebhookH\x00\x42\x0e\n\x0cnotification\"(\n\x15PostSlackNotification\x12\x0f\n\x07webhook\x18\x01 \x01(\t\"\xae\x02\n\rCustomWebhook\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x37\n\x0bhttp_method\x18\x02 \x01(\x0e\x32\".qwak.automation.v1.HttpMethodType\x12?\n\x07headers\x18\x03 \x03(\x0b\x32..qwak.automation.v1.CustomWebhook.HeadersEntry\x12\x39\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32+.qwak.automation.v1.CustomWebhook.DataEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01*\xd1\x01\n\x0eHttpMethodType\x12\x1c\n\x18HTTP_METHOD_TYPE_INVALID\x10\x00\x12\x18\n\x14HTTP_METHOD_TYPE_GET\x10\x01\x12\x19\n\x15HTTP_METHOD_TYPE_POST\x10\x02\x12\x18\n\x14HTTP_METHOD_TYPE_PUT\x10\x03\x12\x1b\n\x17HTTP_METHOD_TYPE_DELETE\x10\x04\x12\x1a\n\x16HTTP_METHOD_TYPE_PATCH\x10\x05\x12\x19\n\x15HTTP_METHOD_TYPE_HEAD\x10\x06\x42!\n\x1d\x63om.qwak.ai.automation.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.automation.v1.notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.automation.api.v1P\001'
  _CUSTOMWEBHOOK_HEADERSENTRY._options = None
  _CUSTOMWEBHOOK_HEADERSENTRY._serialized_options = b'8\001'
  _CUSTOMWEBHOOK_DATAENTRY._options = None
  _CUSTOMWEBHOOK_DATAENTRY._serialized_options = b'8\001'
  _globals['_HTTPMETHODTYPE']._serialized_start=581
  _globals['_HTTPMETHODTYPE']._serialized_end=790
  _globals['_NOTIFICATION']._serialized_start=62
  _globals['_NOTIFICATION']._serialized_end=231
  _globals['_POSTSLACKNOTIFICATION']._serialized_start=233
  _globals['_POSTSLACKNOTIFICATION']._serialized_end=273
  _globals['_CUSTOMWEBHOOK']._serialized_start=276
  _globals['_CUSTOMWEBHOOK']._serialized_end=578
  _globals['_CUSTOMWEBHOOK_HEADERSENTRY']._serialized_start=487
  _globals['_CUSTOMWEBHOOK_HEADERSENTRY']._serialized_end=533
  _globals['_CUSTOMWEBHOOK_DATAENTRY']._serialized_start=535
  _globals['_CUSTOMWEBHOOK_DATAENTRY']._serialized_end=578
# @@protoc_insertion_point(module_scope)



import grpc


from dependency_injector import containers, providers
from qwak.inner.tool.grpc.grpc_tools import (
    create_grpc_channel,
    create_grpc_channel_or_none,
)


class QwakContainer(containers.DeclarativeContainer):
    """
    Qwak CLI dependencies
    """

    config = providers.Configuration(strict=True)

    core_grpc_channel = providers.Singleton(
        create_grpc_channel,
        url=config.grpc.core.address,
        enable_ssl=config.grpc.core.enable_ssl,
        status_for_retry=(
            grpc.StatusCode.UNAVAILABLE,
            grpc.StatusCode.CANCELLED,
            grpc.StatusCode.DEADLINE_EXCEEDED,
        ),
    )

    unauthenticated_core_grpc_channel = providers.Singleton(
        create_grpc_channel,
        url=config.grpc.core.address,
        enable_ssl=config.grpc.authentication.enable_ssl,
        enable_auth=False,
    )

    internal_grpc_channel_for_builds_orchestrator_factory = providers.Singleton(
        create_grpc_channel_or_none,
        url=config.grpc.builds.internal_address,
        enable_ssl=config.grpc.builds.enable_ssl,
        enable_auth=False,
        status_for_retry=(
            grpc.StatusCode.UNAVAILABLE,
            grpc.StatusCode.DEADLINE_EXCEEDED,
        ),
    )



from abc import ABC, abstractmethod
from typing import Optional

from _qwak_proto.qwak.feature_store.v1.common.jfrog_artifact.jfrog_artifact_pb2 import (
    JfrogArtifact as ProtoJfrogArtifact,
)
from _qwak_proto.qwak.feature_store.v1.common.source_code.source_code_pb2 import (
    SourceCodeArtifact as ProtoSourceCodeArtifact,
    SourceCodeSpec as ProtoSourceCodeSpec,
    ZipArtifact as ProtoZipArtifact,
)
from pydantic import BaseModel, Field, model_validator
from qwak.exceptions import QwakException
from typing_extensions import Self


class JfrogArtifact(BaseModel):
    path: str

    @classmethod
    def from_proto(cls, proto: ProtoJfrogArtifact) -> "JfrogArtifact":
        return cls(path=proto.path)

    def to_proto(self) -> ProtoJfrogArtifact:
        return ProtoJfrogArtifact(path=self.path)


class SourceCodeArtifact(BaseModel, ABC):
    @abstractmethod
    def _to_proto(self) -> ProtoSourceCodeArtifact:
        pass


class ZipArtifact(SourceCodeArtifact):
    main_file: str
    qwak_artifact_path: Optional[str] = None
    jfrog_artifact_path: Optional[JfrogArtifact] = None

    @model_validator(mode="after")
    def validate_only_one_artifact_path_type_provided(self: Self) -> Self:
        """
        Ensures that either 'qwak_artifact_path' or 'jfrog_artifact_path' is provided,
        but not both.
        """
        if (self.qwak_artifact_path is None) == (self.jfrog_artifact_path is None):
            raise QwakException(
                "Either `qwak_artifact_path` or `jfrog_artifact_path` must be provided."
            )
        return self

    @classmethod
    def _from_proto(cls, proto: ProtoSourceCodeArtifact) -> "ZipArtifact":
        artifact_type: str = proto.WhichOneof("type")
        if artifact_type != "zip_artifact":
            raise QwakException(
                f"Instead of `zip_artifact` got: {artifact_type}"  # noqa
            )

        artifact_path_type: str = proto.zip_artifact.WhichOneof("path_type")
        jfrog_artifact_path: Optional[JfrogArtifact] = None
        qwak_artifact_path: Optional[str] = None

        if artifact_path_type == "jfrog_artifact_path":
            jfrog_artifact_path = JfrogArtifact.from_proto(
                proto.zip_artifact.jfrog_artifact_path
            )
        elif artifact_path_type == "path":
            qwak_artifact_path = proto.zip_artifact.path
        else:
            raise QwakException(
                "Either `path` or `jfrog_artifact_path` must be provided inside SourceCodeArtifact proto."
            )

        return cls(
            jfrog_artifact_path=jfrog_artifact_path,
            qwak_artifact_path=qwak_artifact_path,
            main_file=proto.zip_artifact.main_file,
        )

    def _to_proto(self) -> ProtoSourceCodeArtifact:
        return ProtoSourceCodeArtifact(
            zip_artifact=ProtoZipArtifact(
                jfrog_artifact_path=(
                    self.jfrog_artifact_path.to_proto()
                    if self.jfrog_artifact_path
                    else None
                ),
                path=self.qwak_artifact_path,
                main_file=self.main_file,
            )
        )


class SourceCodeSpec(BaseModel):
    artifact: Optional[SourceCodeArtifact] = Field(default=None)

    @classmethod
    def _from_proto(cls, proto: ProtoSourceCodeSpec) -> "SourceCodeSpec":
        artifact_type: str = proto.artifact.WhichOneof("type")
        if artifact_type == "zip_artifact":
            return cls(artifact=ZipArtifact._from_proto(proto.artifact))

        return cls(artifact=None)

    def _to_proto(self) -> ProtoSourceCodeSpec:
        if self.artifact:
            return ProtoSourceCodeSpec(artifact=self.artifact._to_proto())
        return ProtoSourceCodeSpec()



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _QwakUserStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _QwakUserStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_QwakUserStatus.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    USER_STATUS_INVALID: _QwakUserStatus.ValueType  # 0
    """Default invalid State"""
    USER_STATUS_ACTIVE: _QwakUserStatus.ValueType  # 1
    """Marks the tenant is currently active in Qwak"""
    USER_STATUS_DISABLED: _QwakUserStatus.ValueType  # 2
    """Marks that the tenant is no longer valid"""

class QwakUserStatus(_QwakUserStatus, metaclass=_QwakUserStatusEnumTypeWrapper): ...

USER_STATUS_INVALID: QwakUserStatus.ValueType  # 0
"""Default invalid State"""
USER_STATUS_ACTIVE: QwakUserStatus.ValueType  # 1
"""Marks the tenant is currently active in Qwak"""
USER_STATUS_DISABLED: QwakUserStatus.ValueType  # 2
"""Marks that the tenant is no longer valid"""
global___QwakUserStatus = QwakUserStatus

class _QwakUserJobFunction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _QwakUserJobFunctionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_QwakUserJobFunction.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    JOB_FUNCTION_INVALID: _QwakUserJobFunction.ValueType  # 0
    """Default invalid job function"""
    JOB_FUNCTION_DATA_ENGINEER: _QwakUserJobFunction.ValueType  # 1
    """Data engineer"""
    JOB_FUNCTION_DATA_SCIENTIST: _QwakUserJobFunction.ValueType  # 2
    """Data scientist"""
    JOB_FUNCTION_ML_ENGINEER: _QwakUserJobFunction.ValueType  # 3
    """ML engineer"""
    JOB_FUNCTION_DEVOPS: _QwakUserJobFunction.ValueType  # 4
    """Devops"""
    JOB_FUNCTION_SOFTWARE_ENGINEER: _QwakUserJobFunction.ValueType  # 5
    """Software engineer"""

class QwakUserJobFunction(_QwakUserJobFunction, metaclass=_QwakUserJobFunctionEnumTypeWrapper): ...

JOB_FUNCTION_INVALID: QwakUserJobFunction.ValueType  # 0
"""Default invalid job function"""
JOB_FUNCTION_DATA_ENGINEER: QwakUserJobFunction.ValueType  # 1
"""Data engineer"""
JOB_FUNCTION_DATA_SCIENTIST: QwakUserJobFunction.ValueType  # 2
"""Data scientist"""
JOB_FUNCTION_ML_ENGINEER: QwakUserJobFunction.ValueType  # 3
"""ML engineer"""
JOB_FUNCTION_DEVOPS: QwakUserJobFunction.ValueType  # 4
"""Devops"""
JOB_FUNCTION_SOFTWARE_ENGINEER: QwakUserJobFunction.ValueType  # 5
"""Software engineer"""
global___QwakUserJobFunction = QwakUserJobFunction

class _QwakUserJobLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _QwakUserJobLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_QwakUserJobLevel.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    JOB_LEVEL_INVALID: _QwakUserJobLevel.ValueType  # 0
    """Default invalid job level"""
    JOB_LEVEL_INDIVIDUAL_CONTRIBUTOR: _QwakUserJobLevel.ValueType  # 1
    """Individual Contributor"""
    JOB_LEVEL_ARCHITECT: _QwakUserJobLevel.ValueType  # 2
    """Architect"""
    JOB_LEVEL_MANAGER: _QwakUserJobLevel.ValueType  # 3
    """Manager"""
    JOB_LEVEL_DIRECTOR: _QwakUserJobLevel.ValueType  # 4
    """Director"""
    JOB_LEVEL_P_OR_VP: _QwakUserJobLevel.ValueType  # 5
    """P/VP"""
    JOB_LEVEL_C_LEVEL: _QwakUserJobLevel.ValueType  # 6
    """C LEVEL"""

class QwakUserJobLevel(_QwakUserJobLevel, metaclass=_QwakUserJobLevelEnumTypeWrapper): ...

JOB_LEVEL_INVALID: QwakUserJobLevel.ValueType  # 0
"""Default invalid job level"""
JOB_LEVEL_INDIVIDUAL_CONTRIBUTOR: QwakUserJobLevel.ValueType  # 1
"""Individual Contributor"""
JOB_LEVEL_ARCHITECT: QwakUserJobLevel.ValueType  # 2
"""Architect"""
JOB_LEVEL_MANAGER: QwakUserJobLevel.ValueType  # 3
"""Manager"""
JOB_LEVEL_DIRECTOR: QwakUserJobLevel.ValueType  # 4
"""Director"""
JOB_LEVEL_P_OR_VP: QwakUserJobLevel.ValueType  # 5
"""P/VP"""
JOB_LEVEL_C_LEVEL: QwakUserJobLevel.ValueType  # 6
"""C LEVEL"""
global___QwakUserJobLevel = QwakUserJobLevel

class _QwakUserKind:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _QwakUserKindEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_QwakUserKind.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    USER_KIND_INVALID: _QwakUserKind.ValueType  # 0
    """Invalid user kind"""
    USER_KIND_QWAK_SIMPLE_USER: _QwakUserKind.ValueType  # 1
    """A regular qwak user"""
    USER_KIND_QWAK_ADMIN: _QwakUserKind.ValueType  # 2
    """Qwak administrator"""
    USER_KIND_QWAK_SERVICE_ACCOUNT_CORE: _QwakUserKind.ValueType  # 3
    """A service account core of qwak infrastructure"""
    USER_KIND_QWAK_SERVICE_ACCOUNT_EDGE: _QwakUserKind.ValueType  # 4
    """A service account edge of qwak infrastructure"""
    USER_KIND_QWAK_SUPPORT: _QwakUserKind.ValueType  # 5
    """Qwak support"""

class QwakUserKind(_QwakUserKind, metaclass=_QwakUserKindEnumTypeWrapper): ...

USER_KIND_INVALID: QwakUserKind.ValueType  # 0
"""Invalid user kind"""
USER_KIND_QWAK_SIMPLE_USER: QwakUserKind.ValueType  # 1
"""A regular qwak user"""
USER_KIND_QWAK_ADMIN: QwakUserKind.ValueType  # 2
"""Qwak administrator"""
USER_KIND_QWAK_SERVICE_ACCOUNT_CORE: QwakUserKind.ValueType  # 3
"""A service account core of qwak infrastructure"""
USER_KIND_QWAK_SERVICE_ACCOUNT_EDGE: QwakUserKind.ValueType  # 4
"""A service account edge of qwak infrastructure"""
USER_KIND_QWAK_SUPPORT: QwakUserKind.ValueType  # 5
"""Qwak support"""
global___QwakUserKind = QwakUserKind

class _QwakAccountRole:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _QwakAccountRoleEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_QwakAccountRole.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACCOUNT_ROLE_INVALID: _QwakAccountRole.ValueType  # 0
    ACCOUNT_ROLE_ADMIN: _QwakAccountRole.ValueType  # 1
    ACCOUNT_ROLE_MAINTAINER: _QwakAccountRole.ValueType  # 3
    ACCOUNT_ROLE_MEMBER: _QwakAccountRole.ValueType  # 2

class QwakAccountRole(_QwakAccountRole, metaclass=_QwakAccountRoleEnumTypeWrapper): ...

ACCOUNT_ROLE_INVALID: QwakAccountRole.ValueType  # 0
ACCOUNT_ROLE_ADMIN: QwakAccountRole.ValueType  # 1
ACCOUNT_ROLE_MAINTAINER: QwakAccountRole.ValueType  # 3
ACCOUNT_ROLE_MEMBER: QwakAccountRole.ValueType  # 2
global___QwakAccountRole = QwakAccountRole

class QwakUserSpec(google.protobuf.message.Message):
    """A qwak user specification
    User is assigned to some tenant, and have access to a closed list of environments. A user has two main access points:
      1. UI Console
      2. SDK / CLI - for which an API Key is generated
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    USER_KIND_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    JOB_FUNCTION_FIELD_NUMBER: builtins.int
    JOB_LEVEL_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Assigned user ID"""
    display_name: builtins.str
    """Display user name"""
    user_kind: global___QwakUserKind.ValueType
    """The kind of the user"""
    status: global___QwakUserStatus.ValueType
    """User status"""
    job_function: global___QwakUserJobFunction.ValueType
    """Job function"""
    job_level: global___QwakUserJobLevel.ValueType
    """Job level"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation date"""
    @property
    def last_modified_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last modification date"""
    time_zone: builtins.str
    """Time zone"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        display_name: builtins.str = ...,
        user_kind: global___QwakUserKind.ValueType = ...,
        status: global___QwakUserStatus.ValueType = ...,
        job_function: global___QwakUserJobFunction.ValueType = ...,
        job_level: global___QwakUserJobLevel.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_modified_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        time_zone: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "last_modified_at", b"last_modified_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "display_name", b"display_name", "id", b"id", "job_function", b"job_function", "job_level", b"job_level", "last_modified_at", b"last_modified_at", "status", b"status", "time_zone", b"time_zone", "user_kind", b"user_kind"]) -> None: ...

global___QwakUserSpec = QwakUserSpec

class QwakUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEC_FIELD_NUMBER: builtins.int
    ENVIRONMENT_IDS_FIELD_NUMBER: builtins.int
    @property
    def spec(self) -> global___QwakUserSpec:
        """User specification"""
    @property
    def environment_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Environment ID's the user has access to"""
    def __init__(
        self,
        *,
        spec: global___QwakUserSpec | None = ...,
        environment_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["environment_ids", b"environment_ids", "spec", b"spec"]) -> None: ...

global___QwakUser = QwakUser



import concurrent.futures
import os
from datetime import datetime, timezone
from enum import Enum
from typing import Dict, List, Optional, Union

from frogml_storage.artifactory import ArtifactoryApi, StartTransactionResponse
from frogml_storage.authentication.models import AuthConfig
from frogml_storage.authentication.utils import get_credentials
from frogml_storage.base_storage import BaseStorage
from frogml_storage.constants import (
    DATASET,
    FROG_ML_DEFAULT_HTTP_THREADS_COUNT,
    FROG_ML_IGNORED_FILES,
    JFML_THREAD_COUNT,
    MODEL,
)
from frogml_storage.exceptions.checksum_verification_error import (
    ChecksumVerificationError,
)
from frogml_storage.exceptions.validation_error import FrogMLValidationError
from frogml_storage.logging import logger
from frogml_storage.logging.log_utils import (
    build_download_success_log,
    build_upload_success_log,
)
from frogml_storage.models import DownloadContext
from frogml_storage.models.dataset_manifest import DatasetManifest
from frogml_storage.models.entity_manifest import Artifact, Checksums, EntityManifest
from frogml_storage.models.frogml_dataset_version import FrogMLDatasetVersion
from frogml_storage.models.frogml_entity_type_info import FrogMLEntityTypeInfo
from frogml_storage.models.frogml_entity_version import FrogMLEntityVersion
from frogml_storage.models.frogml_model_version import FrogMLModelVersion
from frogml_storage.models.model_manifest import ModelManifest
from frogml_storage.models.serialization_metadata import SerializationMetadata
from frogml_storage.utils import (
    assemble_artifact_url,
    calculate_sha2,
    is_not_none,
    is_valid_thread_number,
    join_url,
    user_input_validation,
    validate_not_folder_paths,
    validate_path_exists,
)


class FileType(Enum):
    REGULAR = 1  # can represent either model or dataset file
    DEPENDENCY = 2
    ARCHIVE = 3


class FrogMLStorage(BaseStorage):
    """
    Repository implementation to download or store model|dataset artifacts, and metrics in Artifactory repository.
    """

    def __init__(self, login_config: Optional[AuthConfig] = None):
        uri, auth = get_credentials(login_config)
        self.uri = assemble_artifact_url(uri)
        self.auth = auth
        self.artifactory_api = ArtifactoryApi(self.uri, self.auth)
        self.__initialize_executor()

    def __initialize_executor(self) -> None:
        thread_count = os.getenv(JFML_THREAD_COUNT)
        if thread_count is None or not is_valid_thread_number(thread_count):
            self.http_threads_count = FROG_ML_DEFAULT_HTTP_THREADS_COUNT
        else:
            self.http_threads_count = int(thread_count)

        self.executor = concurrent.futures.ThreadPoolExecutor(
            max_workers=self.http_threads_count
        )

    def upload_dataset_version(
        self,
        repository: str,
        dataset_name: str,
        dataset_path: str,
        namespace: Optional[str] = None,
        version: Optional[str] = None,
        properties: Optional[dict[str, str]] = None,
    ) -> FrogMLDatasetVersion:
        return FrogMLDatasetVersion.from_entity_version(
            self.__upload_entity_version(
                repository=repository,
                entity_name=dataset_name,
                source_path=dataset_path,
                entity_type=DATASET,
                namespace=namespace,
                version=version,
                properties=properties,
            )
        )

    def upload_model_version(
        self,
        repository: str,
        model_name: str,
        model_path: str,
        model_type: Union[SerializationMetadata, Dict],
        namespace: Optional[str] = None,
        version: Optional[str] = None,
        properties: Optional[dict[str, str]] = None,
        dependencies_files_paths: Optional[List[str]] = None,
        code_archive_file_path: Optional[str] = None,
    ) -> FrogMLModelVersion:

        is_not_none("model_type", model_type)
        if isinstance(model_type, Dict):
            logger.debug(
                "received dictionary model_type, converting to SerializationMetadata"
            )
            model_type = SerializationMetadata.from_json(model_type)
        validate_not_folder_paths(dependencies_files_paths)
        validate_not_folder_paths(code_archive_file_path)
        validate_path_exists(model_path)

        return FrogMLModelVersion.from_entity_version(
            self.__upload_entity_version(
                repository=repository,
                entity_name=model_name,
                source_path=model_path,
                entity_type=MODEL,
                model_type=model_type,
                namespace=namespace,
                version=version,
                properties=properties,
                dependencies_files_paths=dependencies_files_paths,
                code_archive_file_path=code_archive_file_path,
            )
        )

    def __upload_entity_version(
        self,
        repository: str,
        entity_name: str,
        source_path: str,
        entity_type: str = "model",
        model_type: Optional[SerializationMetadata] = None,
        namespace: Optional[str] = None,
        version: Optional[str] = None,
        properties: Optional[dict[str, str]] = None,
        dependencies_files_paths: Optional[List[str]] = None,
        code_archive_file_path: Optional[str] = None,
    ) -> FrogMLEntityVersion:
        try:
            self.__verify_upload_required_args_not_none(
                repository=repository, entity_name=entity_name, source_path=source_path
            )

            user_input_validation(
                entity_name=entity_name,
                namespace=namespace,
                version=version,
                properties=properties,
            )

            validate_path_exists(source_path)

            namespace_and_name = self.__union_entity_name_with_namespace(
                namespace, entity_name
            )

            entity_type_info = FrogMLEntityTypeInfo.from_string(entity_type)
            response: StartTransactionResponse = self.artifactory_api.start_transaction(
                entity_type_info=entity_type_info,
                repository=repository,
                entity_name=namespace_and_name,
                version=version,
            )

            if version is None:
                version = response.files_upload_path.replace(
                    f"{entity_type_info.folder_name}/{namespace_and_name}/tmp/",  # nosec B108
                    "",
                ).split("/")[0]
                logger.debug(
                    "Version was not specified. Setting version to {}".format(version)
                )

            transaction_date = self.__milliseconds_to_iso_instant(
                response.transaction_id
            )

            entity_manifest: Union[ModelManifest, DatasetManifest]
            if entity_type_info == FrogMLEntityTypeInfo.MODEL:
                if not isinstance(model_type, SerializationMetadata):
                    raise AssertionError(
                        f"model_type must be {SerializationMetadata.__name__}"
                    )

                entity_manifest = ModelManifest(
                    created_date=transaction_date,
                    artifacts=[],
                    model_format=model_type,
                )
                self.__upload_model(
                    source_path=source_path,
                    repository=repository,
                    files_upload_path=response.files_upload_path,
                    dependencies_upload_path=response.dependencies_upload_path,
                    code_upload_path=response.code_upload_path,
                    entity_name=entity_name,
                    version=version,
                    entity_type_info=entity_type_info,
                    model_manifest=entity_manifest,
                    dependency_files=dependencies_files_paths,
                    code_file=code_archive_file_path,
                )
            else:
                entity_manifest = DatasetManifest(
                    created_date=transaction_date,
                    artifacts=[],
                )
                self.__upload_dataset(
                    source_path=source_path,
                    repository=repository,
                    location_to_upload=response.files_upload_path,
                    entity_name=entity_name,
                    version=version,
                    entity_type_info=entity_type_info,
                    dataset_manifest=entity_manifest,
                )

            self.artifactory_api.end_transaction(
                entity_type=entity_type_info,
                repository=repository,
                entity_name=namespace_and_name,
                entity_manifest=entity_manifest,
                transaction_id=response.transaction_id,
                version=version,
                properties=properties,
            )

            return FrogMLEntityVersion(
                entity_name=entity_name,
                namespace=namespace,
                version=version,
                entity_manifest=entity_manifest,
            )

        except FrogMLValidationError as error:
            logger.error(error.args[0], exc_info=False)

        return FrogMLEntityVersion(
            entity_name="", namespace="", version="", entity_manifest=None
        )

    def download_dataset_version(
        self,
        repository: str,
        dataset_name: str,
        version: str,
        target_path: str,
        namespace: Optional[str] = None,
    ) -> None:
        return self.__download_entity_version(
            repository=repository,
            entity_name=dataset_name,
            version=version,
            target_path=target_path,
            entity_type=DATASET,
            namespace=namespace,
        )

    def download_model_version(
        self,
        repository: str,
        model_name: str,
        version: str,
        target_path: str,
        namespace: Optional[str] = None,
    ) -> None:
        return self.__download_entity_version(
            repository=repository,
            entity_name=model_name,
            version=version,
            target_path=target_path,
            entity_type=MODEL,
            namespace=namespace,
        )

    def __download_entity_version(
        self,
        repository: str,
        entity_name: str,
        version: str,
        target_path: str,
        entity_type: str,
        namespace: Optional[str] = None,
    ) -> None:
        try:
            self.__verify_download_required_args_not_none(
                repository=repository,
                entity_name=entity_name,
                version=version,
                target_path=target_path,
            )
            user_input_validation(
                entity_name=entity_name, version=version, namespace=namespace
            )

            entity_type_info = FrogMLEntityTypeInfo.from_string(entity_type)

            download_context_list = self._get_download_context_list(
                entity_type_info=entity_type_info,
                repository=repository,
                entity_name=entity_name,
                version=version,
                target_dir_path=target_path,
                namespace=namespace,
            )

            if len(download_context_list) == 0:
                logger.info(
                    f"No files to download for {entity_type_info.entity_type}: '{entity_name}' version: '{version}'"
                )
                return
            for download_context in download_context_list[:]:
                if download_context.exists_locally:
                    logger.info(
                        f"File '{download_context.target_path}' already exists locally, will not download it."
                    )
                    download_context_list.remove(download_context)
                elif not self.__is_checksum_valid(download_context):
                    raise ChecksumVerificationError(
                        os.path.basename(download_context.target_path)
                    )

            successfully_downloaded = self._execute_parallel_download(
                download_context_list
            )

            if successfully_downloaded:
                successful_log = build_download_success_log(
                    entity_type_info, entity_name, version
                )
                logger.info(successful_log)

        except FrogMLValidationError as error:
            logger.error(error.args[0], exc_info=False)
        except Exception as e:
            logger.error(
                f"An error occurred during download_entity_version: {e}", exc_info=False
            )
            raise e

    def __is_checksum_valid(self, download_arg: DownloadContext) -> bool:
        if not download_arg.artifact_checksum:
            return False
        return (
            download_arg.artifact_checksum.sha2
            == self.artifactory_api.get_artifact_checksum(download_arg)
        )

    def _get_download_context_list(
        self,
        entity_type_info: FrogMLEntityTypeInfo,
        repository: str,
        entity_name: str,
        version: str,
        target_dir_path: str,
        namespace: Optional[str] = None,
    ) -> List[DownloadContext]:
        download_context_list = []
        entity_manifest = self.artifactory_api.get_entity_manifest(
            entity_type_info,
            repository,
            entity_name,
            namespace,
            version,
        )
        search_under_repo = f"/{repository}/"

        for artifact in entity_manifest[
            (
                "model_artifacts"
                if entity_type_info == FrogMLEntityTypeInfo.MODEL
                else "dataset_artifacts"
            )
        ]:
            download_url = artifact["download_url"]
            artifact_path = artifact["artifact_path"]
            artifact_checksum = Checksums(**artifact["checksums"])
            target_path = os.path.join(target_dir_path, artifact_path)
            position_under_repo = download_url.find(search_under_repo)
            if position_under_repo != -1:
                repo_rel_path = download_url[
                    position_under_repo + len(search_under_repo) :
                ]

                args = DownloadContext(
                    repo_key=repository,
                    source_url=repo_rel_path,
                    target_path=target_path,
                    artifact_checksum=artifact_checksum,
                )

                if not os.path.exists(target_path):
                    self.__create_dirs_if_needed(target_dir_path, artifact_path)
                else:
                    args.exists_locally = True
                download_context_list.append(args)
        return download_context_list

    def _execute_parallel_download(
        self, download_context_list: List[DownloadContext]
    ) -> int:
        if len(download_context_list) == 0:
            logger.debug("No files to download.")
            return 0
        logger.debug(f"Fetching: {len(download_context_list)} files.")
        futures = []
        for download_arg in download_context_list:
            future = self.executor.submit(
                self.artifactory_api.download_file, download_arg
            )
            futures.append(future)
        return self.__submit_and_handle_futures(futures)

    def get_entity_manifest(
        self,
        entity_type: str,
        repository: str,
        namespace: Optional[str],
        entity_name: str,
        version: Optional[str],
    ) -> dict:
        entity_type_info = FrogMLEntityTypeInfo.from_string(entity_type)
        return self.artifactory_api.get_entity_manifest(
            entity_type_info=entity_type_info,
            repository=repository,
            entity_name=entity_name,
            namespace=namespace,
            version=version,
        )

    def __upload_by_source(
        self,
        source_path: str,
        repository: str,
        location_to_upload: str,
        file_type: FileType,
        entity_manifest: Optional[EntityManifest] = None,
    ) -> bool:
        if os.path.isfile(source_path):
            rel_path = os.path.basename(source_path)
            self.__upload_single_file(
                (
                    repository,
                    source_path,
                    rel_path,
                    location_to_upload,
                    file_type,
                    entity_manifest,
                )
            )
            return True

        else:
            futures = []
            for dir_path, dir_names, file_names in os.walk(source_path):
                for filename in file_names:
                    full_path = os.path.join(dir_path, filename)
                    rel_path = os.path.relpath(full_path, source_path)
                    future = self.executor.submit(
                        self.__upload_single_file,
                        (
                            repository,
                            full_path,
                            rel_path,
                            location_to_upload,
                            file_type,
                            entity_manifest,
                        ),
                    )
                    futures.append(future)

            successfully_uploaded = self.__submit_and_handle_futures(futures)

            if successfully_uploaded > 0:
                return True
            return False

    def __upload_model(
        self,
        source_path: str,
        repository: str,
        files_upload_path: str,
        dependencies_upload_path: str,
        code_upload_path: str,
        entity_name: str,
        version: str,
        entity_type_info: FrogMLEntityTypeInfo,
        model_manifest: ModelManifest,
        dependency_files: Optional[List[str]] = None,
        code_file: Optional[str] = None,
    ) -> None:
        logger.debug("Uploading model files...")
        is_successful_upload: bool = self.__upload_by_source(
            source_path,
            repository,
            files_upload_path,
            FileType.REGULAR,
            model_manifest,
        )
        logger.debug("Uploading model requirement files...")
        if dependency_files is not None:
            for dependency_file in dependency_files:
                is_successful_upload &= self.__upload_by_source(
                    dependency_file,
                    repository,
                    dependencies_upload_path,
                    FileType.DEPENDENCY,
                    model_manifest,
                )
        logger.debug("Uploading model code archive file...")
        if code_file is not None:
            is_successful_upload &= self.__upload_by_source(
                code_file,
                repository,
                code_upload_path,
                FileType.ARCHIVE,
                model_manifest,
            )
        if is_successful_upload:
            successful_log = build_upload_success_log(
                entity_type_info, entity_name, version
            )
            logger.info(successful_log)

    def __upload_dataset(
        self,
        source_path: str,
        repository: str,
        location_to_upload: str,
        entity_name: str,
        version: str,
        entity_type_info: FrogMLEntityTypeInfo,
        dataset_manifest: DatasetManifest,
    ) -> None:
        logger.debug("Uploading dataset files...")
        is_successful_upload: bool = self.__upload_by_source(
            source_path=source_path,
            repository=repository,
            location_to_upload=location_to_upload,
            file_type=FileType.REGULAR,
            entity_manifest=dataset_manifest,
        )
        if is_successful_upload:
            successful_log = build_upload_success_log(
                entity_type_info, entity_name, version
            )
            logger.info(successful_log)

    @staticmethod
    def __submit_and_handle_futures(futures: list) -> int:
        failed_futures = []
        for future in futures:
            try:
                future.result()
            except Exception as e:
                failed_futures.append(e.args)

        if len(failed_futures) > 0:
            for failed_future in failed_futures:
                logger.error(f"{failed_future}")

        return len(futures) - len(failed_futures)

    def __upload_single_file(self, args):
        (
            repository,
            full_path,
            rel_path,
            location_to_upload,
            file_type,
            entity_manifest,
        ) = args
        if not FrogMLStorage.__is_ignored_file(full_path=full_path):
            checksums = Checksums.calc_checksums(full_path)
            if entity_manifest is not None:
                if file_type == FileType.REGULAR:
                    entity_manifest.add_file(full_path, checksums, rel_path)
                elif file_type == FileType.DEPENDENCY:
                    entity_manifest.add_dependency_file(full_path, checksums, rel_path)
                elif file_type == FileType.ARCHIVE:
                    entity_manifest.code_artifacts = Artifact(
                        artifact_path=rel_path,
                        size=os.path.getsize(full_path),
                        checksums=checksums,
                    )
            url = join_url(self.uri, repository, location_to_upload, rel_path)
            is_checksum_deploy_success = self.artifactory_api.checksum_deployment(
                url=url, checksum=checksums, full_path=full_path, stream=True
            )
            if is_checksum_deploy_success is False:
                self.artifactory_api.upload_file(url=url, file_path=full_path)

    @staticmethod
    def __calculate_sha2_no_error(file_path: str) -> Optional[str]:
        # Used to calculate sha2 without raising an exception
        if os.path.exists(file_path) is False:
            logger.debug(f"File {file_path} does not exist, can't calculate sha256")
            return None
        try:
            return calculate_sha2(file_path)
        except Exception as e:
            logger.debug(f"Failed to calculate sha256 for file {file_path}. Error: {e}")
            return None

    @staticmethod
    def __verify_download_required_args_not_none(
        repository: str, entity_name: str, version: str, target_path: str
    ) -> bool:
        is_not_none("repository", repository)
        is_not_none("entity_name", entity_name)
        is_not_none("version", version)
        is_not_none("target_path", target_path)
        return True

    @staticmethod
    def __verify_upload_required_args_not_none(
        repository: str, entity_name: str, source_path: str
    ) -> bool:
        is_not_none("repository", repository)
        is_not_none("entity_name", entity_name)
        is_not_none("source_path", source_path)
        return True

    @staticmethod
    def __is_ignored_file(full_path: str) -> bool:
        normalized_path = os.path.normpath(full_path).lower()
        parts = normalized_path.split(os.sep)
        ignored_files_lower = [item.lower() for item in FROG_ML_IGNORED_FILES]

        for part in parts:
            if part in ignored_files_lower:
                return True
        return False

    @staticmethod
    def __union_entity_name_with_namespace(
        namespace: Optional[str], entity_name: str
    ) -> str:
        if namespace is None:
            return entity_name
        else:
            return namespace + "/" + entity_name

    @staticmethod
    def __create_dirs_if_needed(base_dir: str, file_uri: str) -> str:
        full_path = os.path.join(base_dir, file_uri.strip("/"))
        dest_path = os.path.dirname(full_path)
        if not os.path.exists(dest_path):
            os.makedirs(dest_path)
        return dest_path

    @staticmethod
    def __milliseconds_to_iso_instant(milliseconds: str) -> str:
        instant: datetime = datetime.fromtimestamp(
            int(milliseconds) / 1000.0, tz=timezone.utc
        )
        x = instant.strftime("%Y-%m-%dT%H:%M:%S.%f")[:-4]
        return x



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.integration import integration_service_pb2 as qwak_dot_integration_dot_integration__service__pb2


class IntegrationManagementServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateIntegration = channel.unary_unary(
                '/qwak.integration.management.IntegrationManagementService/CreateIntegration',
                request_serializer=qwak_dot_integration_dot_integration__service__pb2.CreateIntegrationRequest.SerializeToString,
                response_deserializer=qwak_dot_integration_dot_integration__service__pb2.CreateIntegrationResponse.FromString,
                )
        self.GetIntegration = channel.unary_unary(
                '/qwak.integration.management.IntegrationManagementService/GetIntegration',
                request_serializer=qwak_dot_integration_dot_integration__service__pb2.GetIntegrationRequest.SerializeToString,
                response_deserializer=qwak_dot_integration_dot_integration__service__pb2.GetIntegrationResponse.FromString,
                )
        self.ListIntegrations = channel.unary_unary(
                '/qwak.integration.management.IntegrationManagementService/ListIntegrations',
                request_serializer=qwak_dot_integration_dot_integration__service__pb2.ListIntegrationRequest.SerializeToString,
                response_deserializer=qwak_dot_integration_dot_integration__service__pb2.ListIntegrationsResponse.FromString,
                )
        self.UpdateIntegration = channel.unary_unary(
                '/qwak.integration.management.IntegrationManagementService/UpdateIntegration',
                request_serializer=qwak_dot_integration_dot_integration__service__pb2.UpdateIntegrationRequest.SerializeToString,
                response_deserializer=qwak_dot_integration_dot_integration__service__pb2.UpdateIntegrationResponse.FromString,
                )
        self.DeleteIntegration = channel.unary_unary(
                '/qwak.integration.management.IntegrationManagementService/DeleteIntegration',
                request_serializer=qwak_dot_integration_dot_integration__service__pb2.DeleteIntegrationRequest.SerializeToString,
                response_deserializer=qwak_dot_integration_dot_integration__service__pb2.DeleteIntegrationResponse.FromString,
                )
        self.ValidateIntegration = channel.unary_unary(
                '/qwak.integration.management.IntegrationManagementService/ValidateIntegration',
                request_serializer=qwak_dot_integration_dot_integration__service__pb2.ValidateIntegrationRequest.SerializeToString,
                response_deserializer=qwak_dot_integration_dot_integration__service__pb2.ValidateIntegrationResponse.FromString,
                )
        self.GetIntegrationOptions = channel.unary_unary(
                '/qwak.integration.management.IntegrationManagementService/GetIntegrationOptions',
                request_serializer=qwak_dot_integration_dot_integration__service__pb2.GetIntegrationOptionsRequest.SerializeToString,
                response_deserializer=qwak_dot_integration_dot_integration__service__pb2.GetIntegrationOptionsResponse.FromString,
                )


class IntegrationManagementServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateIntegration(self, request, context):
        """Create a new integration in account level
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegration(self, request, context):
        """Get integration by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListIntegrations(self, request, context):
        """List Integrations for account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateIntegration(self, request, context):
        """Update Integration by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegration(self, request, context):
        """Delete Integration by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateIntegration(self, request, context):
        """Validate a integration details before creating one.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationOptions(self, request, context):
        """Get Integrations additional options
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IntegrationManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIntegration,
                    request_deserializer=qwak_dot_integration_dot_integration__service__pb2.CreateIntegrationRequest.FromString,
                    response_serializer=qwak_dot_integration_dot_integration__service__pb2.CreateIntegrationResponse.SerializeToString,
            ),
            'GetIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegration,
                    request_deserializer=qwak_dot_integration_dot_integration__service__pb2.GetIntegrationRequest.FromString,
                    response_serializer=qwak_dot_integration_dot_integration__service__pb2.GetIntegrationResponse.SerializeToString,
            ),
            'ListIntegrations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIntegrations,
                    request_deserializer=qwak_dot_integration_dot_integration__service__pb2.ListIntegrationRequest.FromString,
                    response_serializer=qwak_dot_integration_dot_integration__service__pb2.ListIntegrationsResponse.SerializeToString,
            ),
            'UpdateIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateIntegration,
                    request_deserializer=qwak_dot_integration_dot_integration__service__pb2.UpdateIntegrationRequest.FromString,
                    response_serializer=qwak_dot_integration_dot_integration__service__pb2.UpdateIntegrationResponse.SerializeToString,
            ),
            'DeleteIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegration,
                    request_deserializer=qwak_dot_integration_dot_integration__service__pb2.DeleteIntegrationRequest.FromString,
                    response_serializer=qwak_dot_integration_dot_integration__service__pb2.DeleteIntegrationResponse.SerializeToString,
            ),
            'ValidateIntegration': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateIntegration,
                    request_deserializer=qwak_dot_integration_dot_integration__service__pb2.ValidateIntegrationRequest.FromString,
                    response_serializer=qwak_dot_integration_dot_integration__service__pb2.ValidateIntegrationResponse.SerializeToString,
            ),
            'GetIntegrationOptions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationOptions,
                    request_deserializer=qwak_dot_integration_dot_integration__service__pb2.GetIntegrationOptionsRequest.FromString,
                    response_serializer=qwak_dot_integration_dot_integration__service__pb2.GetIntegrationOptionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.integration.management.IntegrationManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class IntegrationManagementService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.integration.management.IntegrationManagementService/CreateIntegration',
            qwak_dot_integration_dot_integration__service__pb2.CreateIntegrationRequest.SerializeToString,
            qwak_dot_integration_dot_integration__service__pb2.CreateIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.integration.management.IntegrationManagementService/GetIntegration',
            qwak_dot_integration_dot_integration__service__pb2.GetIntegrationRequest.SerializeToString,
            qwak_dot_integration_dot_integration__service__pb2.GetIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListIntegrations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.integration.management.IntegrationManagementService/ListIntegrations',
            qwak_dot_integration_dot_integration__service__pb2.ListIntegrationRequest.SerializeToString,
            qwak_dot_integration_dot_integration__service__pb2.ListIntegrationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.integration.management.IntegrationManagementService/UpdateIntegration',
            qwak_dot_integration_dot_integration__service__pb2.UpdateIntegrationRequest.SerializeToString,
            qwak_dot_integration_dot_integration__service__pb2.UpdateIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.integration.management.IntegrationManagementService/DeleteIntegration',
            qwak_dot_integration_dot_integration__service__pb2.DeleteIntegrationRequest.SerializeToString,
            qwak_dot_integration_dot_integration__service__pb2.DeleteIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateIntegration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.integration.management.IntegrationManagementService/ValidateIntegration',
            qwak_dot_integration_dot_integration__service__pb2.ValidateIntegrationRequest.SerializeToString,
            qwak_dot_integration_dot_integration__service__pb2.ValidateIntegrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetIntegrationOptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.integration.management.IntegrationManagementService/GetIntegrationOptions',
            qwak_dot_integration_dot_integration__service__pb2.GetIntegrationOptionsRequest.SerializeToString,
            qwak_dot_integration_dot_integration__service__pb2.GetIntegrationOptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
